##################################################################################################################################
#' Cylinder Bands
#' 
#' @name bands
#'
#'
#' @description Questo dataset è connesso con ritardi di processo noti come cylinder banding (presenza di bande del cilindro) nella stampa rotativa.
#' 
#' Il dataset completo è stato descritto ed analizzado in [Moro et al., 2011]., si veda la sezione \code{fonti}.
#'
#'
#' @usage data(bands)
#' 
#' 
#' @format \code{bands} è un data frame tbl con 540 osservazioni su 40 variabili.
#' 
#'  
#' @details 
#' Le 40 variabili sono organizzate come segue.
#' 
#' \itemize{
#' \item \code{timestamp} (numerico da 19900330 a 19941010);
#' \item \code{cylinder_number} (character);
#' \item \code{customer} (character);
#' \item \code{job_number} (numerico da 23040 a 88231) 
#' \item \code{grain_screened} (fattore con 2 livelli: YES, NO);
#' \item \code{ink_color} (fattore con 1 livello: KEY);
#' \item \code{proof_on_ctd_ink} (fattore con 2 livelli: YES, NO);
#' \item \code{blade_mfg} (fattore con 2 livelli: BENTON, UDDEHOLM);
#' \item \code{cylinder_division} (fattore con 1 livello: GALLATIN);
#' \item \code{paper_type} (fattore con 3 livelli: UNCOATED, COATED, SUPER);
#' \item \code{ink_type} (fattore con 3 livelli: UNCOATED, COATED, COVER); 
#' \item \code{direct_steam} (fattore con 2 livelli: YES, NO);
#' \item \code{solvent_type} (fattore con 3 livelli: LINE, NAPTHA, XYLOL);
#' \item \code{type_on_cylinder} (fattore con 2 livelli: YES, NO);
#' \item \code{press_type} (fattore con 4 livelli: ALBERT70, MOTTER70, MOTTER94, WOODHOE70);
#' \item \code{press} (numeric da 802 a 828)
#' \item \code{unit_number}: unità di stampa (numerico: 1-10)
#' \item \code{cylinder_size} (fattore con 3 livelli: CATALOG, SPIEGEL, TABLOID);
#' \item \code{paper_mill_location} (fattore con 5 livelli: CANADIAN, MIDEUROPEAN, NORTHUS, SCANDANAVIAN, SOUTHUS);
#' \item \code{plating_tank} (numerico: 1910, 1911);
#' \item \code{proof_cut} misurato in percentuale (numerico: 0-100);
#' \item \code{viscosity} misurato in percentuale (numerico: 0-100);
#' \item \code{caliper} misurato in percentuale (numerico: 0-1);
#' \item \code{ink_temperature} misurato in gradi Fahrenheit (numerico: 5-30);
#' \item \code{humidity} misurato in percentuale (numerico: 5-105);
#' \item \code{roughness} misurato in micron (numerico: 0-2);
#' \item \code{blade_pressure} misurato in once (numerico: 10-75);
#' \item \code{varnish_pct} misurato in percentuale (numerico: 0-100);
#' \item \code{press_speed} misurato in piedi al minuto (numerico: 0-4000);
#' \item \code{ink_pct} misurato in percentuale (numerico: 0-100);
#' \item \code{solvent_pct} misurato in percentuale (numerico: 0-100);
#' \item \code{esa_voltage} misurato in kilovolt (numerico: 0-16);
#' \item \code{esa_amperage} misurato in milliampère (numerico: 0-10);
#' \item \code{wax} misurato in galloni (numerico: 0-4);
#' \item \code{hardener} misurato in galloni (numerico: 0-3.0);
#' \item \code{roller_durometer} (numerico: 15-120);
#' \item \code{current_density} misurato in ampère per decimetro quadrato (numerico: 20-50);
#' \item \code{anode_space_ratio} (numerico: 70-130);
#' \item \code{chrome_content} (numerico: 80-120);
#' \item \code{band_type} (fattore con 2 livelli: BAND, NOBAND).
#' }
#' 
#' 
#' @source Questo dataset è disponibile pubblicamente presso \href{http://archive.ics.uci.edu/ml/datasets/Cylinder+Bands}{UCI Machine Learning repository}.
#' 
#' Per cortesia includete questa citazione se pensate di usare questo dataset:\cr
#' Lichman, M. (2013). UCI Machine Learning Repository [\url{http://archive.ics.uci.edu/ml}]. Irvine, CA: University of California, School of Information and Computer Science.
#' 
#' The dataset was created and donated on 08 Jan 1995 to \href{http://archive.ics.uci.edu/ml/datasets/Cylinder+Bands}{UCI Machine Learning repository} by:\cr
#' Bob Evans 
#' RR Donnelley & Sons Co. 
#' Gallatin Division 
#' 801 Steam Plant Rd 
#' Gallatin, Tennessee 37066-3396 
#' (615) 452-5170 
NULL
##################################################################################################################################


##################################################################################################################################
#' Campagne di Marketing di un Istituto Bancario Portoghese
#' 
#' 
#' @name bank
#' 
#' 
#' @description Questo dataset contiene informazioni su campagne di marketing diretto di un istituto di credito portuguese.
#' Le campagne di marketing erano di tipo telefonico. 
#' Spesso risultavano necesari più contatti con lo stesso cliente, per poter avere conferma che il prodotto (deposito bancario a termine) fosse ('yes') o non fosse ('no') stato sottoscritto. 
#' 
#' Il dataset completo è stato descritto ed analizzato in [Moro et al., 2011]; si veda la sezione \code{fonti}.
#' 
#'  
#' @usage data(bank) 
#' 
#' 
#' @format \code{bank} è un data frame tbl con 45211 osservazioni su 20 variabili.
#' 
#' I dati sono ordinati per call id (ed anche per data, da Maggio 2008 a Novembre 2010). 
#' 
#' 
#' @details 
#' Le 20 variabili sono organizzate come segue.
#' 
#' Dati dei clienti della banca:
#' \itemize{
#' \item \code{id} id della chiamata (integer: da 1 a 45211);
#' \item \code{age} età (integer);
#' \item \code{job} tipo di lavoro (fattore con 12 livelli: admin., unknown, unemployed, management, housemaid, entrepreneur, student,  blue-collar, self-employed, retired, technician, services);
#' \item \code{marital} stato coniugale (fattore con 3 livelli: married, divorced, single). divorced indica divorziato o vedovo;
#' \item \code{education} livello istruzione (fattore con 4 livelli: unknown, secondary, primary, tertiary);
#' \item \code{default} ha credito in default? (fattore con 2 livelli: yes, no);
#' \item \code{balance} bilancio annuale medio, in euro (integer);
#' \item \code{housing} ha prestiti per la casa? (fattore con 2 levelli: yes, no);
#' \item \code{loan} ha prestiti personali? (fattori con 2 livelli: yes, no).
#' }
#' Dati connessi con l'ultimo contatto della campagna corrente:
#' \itemize{
#' \item \code{contact} tipo di comunicazione di contatto (fattore con 3 livelli: unknown, telephone, cellular);
#' \item \code{day} giorno del mese dell'ultimo contatto (integer);
#' \item \code{month} mese dell'anno dell'ultimo contatto (fattore con 12 livelli: jan, feb, mar, ..., nov, dec);
#' \item \code{year} anno dell'ultimo contatto (integer: 2008, 2009, 2010);
#' \item \code{date} data dell'ultimo contatto (\code{POSIXct} date);
#' \item \code{duration} durata dell'ultimo contatto, in secondi (integer);
#' \item \code{y} il cliente ha sottoscritto un deposito a termine? (fattore con 2 livelli: yes, no).
#' }
#' Altri attributi:
#' \itemize{
#' \item \code{campaign} numero di contatti avuti in questa campagna e questo cliente (integer: include l'ultimo contatto);
#' \item \code{pdays} numero di giorni trascorsi dopo che il cliente è stato contattato l'ultima volta per una campagna precedente (integer). -1 significa che il cliente non era stato contattato in precedenza;
#' \item \code{previous} numero di contatti avuti prima di questa campagna e questo cliente (integer);
#' \item \code{poutcome} risultato della campagna di marketing precedente (fattore con 4 livelli: unknown, other, failure, success).
#' }
#' 
#' 
#' @source Questo dataset è disponibile pubblicamente per ricerca presso \href{http://archive.ics.uci.edu/ml/datasets/Bank+Marketing}{UCI Machine Learning repository}.
#' I dettagli sono descritti in [Moro et al., 2011]. 
#' 
#' Per cortesia includete questa citazione se pensate di usare questo dataset:\cr
#' [Moro et al., 2011] S. Moro, R. Laureano and P. Cortez. Using Data Mining for Bank Direct Marketing: An Application of the CRISP-DM Methodology.  
#' In P. Novais et al. (Eds.), \emph{Proceedings of the European Simulation and Modelling Conference - ESM'2011}, pp. 117-121, Guimarães, Portugal, October, 2011. EUROSIS.\cr
#' Disponibile all'indirizzo \url{http://hdl.handle.net/1822/14838}.
NULL
##################################################################################################################################


##################################################################################################################################
#' Banconote Svizzere
#' 
#' 
#' @name banknotes
#' 
#' 
#' @description Questo dataset contiene i dati di 200 vecchie banconote da 1000 franchi svizzeri, classificate per dimensioni (6 caratteristiche numeriche) e tipo (genuine/contraffatte).
#' Le prime 100 banconote sono genuine, le ultime 100 sono contraffatte.
#' 
#'  
#' @usage data(banknotes)
#' 
#' 
#' @format \code{banknotes} è un data frame tbl con 200 osservazioni su 7 variabili.
#' 
#' 
#' @details 
#' Le 7 variabili del data frame tbl \code{banknotes} sono le seguenti:
#' \itemize{
#' \item \code{length} lunghezza della banconota (numerico);
#' \item \code{left} altezza della banconota, misurata a sinistra (cu.in.) (numerico);
#' \item \code{right} altezza della banconota, misurata a destra (numerico);
#' \item \code{bottom} distanza del riquadro interno dal bordo inferiore (numerico);
#' \item \code{top} distanza del riquadro interno dal bordo superiore (numerico);
#' \item \code{diagonal} lunghezza della diagonale (numerico);
#' \item \code{type} se la banconota è genuina o contraffatta (Fattore con 2 livelli: genuine, counterfeit).
#' }
#' 
#' 
#' @source Härdle and Simar, Applied Multivariate Statistical Analysis, 3rd ed., Springer, 2012
NULL
##################################################################################################################################


##################################################################################################################################
#' Dataset Bimetal in Phase I
#' 
#' 
#' @name bimetal1
#' 
#' 
#' @description I dati \code{bimetal1} sono stati estratti dall'analogo data frame del package \code{MSQC}. 
#' Il dataset contiene misurazioni di deflessione, curvatura, resistività e durezza nei lati di bassa e alta espansione,
#' da termostati bimetallici in ottone e acciaio. Il processo produttivo è assunto essere "sotto controllo".
#' 
#'  
#' @usage data(bimetal1)
#' 
#' 
#' @format \code{bimetal1} è un data frame tbl con 28 osservazioni su 5 variabili.
#' 
#' 
#' @details 
#' Le 5 variabili del data frame tbl \code{bimetal1} sono:
#' \itemize{
#' \item \code{deflection} il livello di deflessione in 10^-6 1/K (numerico);
#' \item \code{curvature} il livello di curvatura in 10^-6 1/K (numerico);
#' \item \code{resistivity} il livello di resistività in 10 ^-1ohm x mm^2/m (numerico);
#' \item \code{Hardness.low.side} la durezza del lato di bassa espansione in 10 N/mm^2 (numerico);
#' \item \code{Hardness.high.side} la durezza del lato di alta espansione in 10 N/mm^3 (numerico).
#' }
#' 
#' 
#' @seealso La pagina di help completa di \code{bimetal1} può essere trovata nel package \code{MSQC}: \code{\link[MSQC]{bimetal1}}
NULL
##################################################################################################################################


##################################################################################################################################
#' Case a Boston
#' 
#' 
#' @name bostonhousing
#' 
#' 
#' @description I dati \code{bostonhousing} contengono informazioni su 506 case di Boston classificate rispetto a 13 caratteristiche numeriche
#' (age, tax, ecc.) ed una caratteristica categoriale (chas).
#' 
#'  
#' @usage data(bostonhousing)
#' 
#' 
#' @format \code{bostonhousing} è un data frame tbl con 506 osservazioni su 14 variabili.
#' 
#' 
#' @details 
#' Le 14 variabili del data frame tbl \code{bostonhousing} sono:
#' \itemize{
#' \item \code{crim} tasso di criminalità per centro urbano (numerico)
#' \item \code{zn} proporzione di terreni residenziali suddivisi in zone per lotti superiori a 25,000 piedi quadrati (numerico)
#' \item \code{indus} proporzione di acri commerciali non al dettaglio per centro urbano (numerico)
#' \item \code{chas} variabile dummy Charles River (= 1 se confina con il fiume; 0 altrimenti) (numerico)
#' \item \code{nox} concentrazione di nitrogen oxides (parti per 10 millioni) (numerico)
#' \item \code{rm} numer medio di stanze per abitazione (numerico)
#' \item \code{age} proporzione di unità occupate dal proprietario costruite prima del 1940 (numerico)
#' \item \code{dis} media pesata delle distanze da cinque centri d'impiego di Boston (numerico)
#' \item \code{rad} indeice di accessibilità da superrstrade periferiche (numerico)
#' \item \code{tax} livello di tassazione sul valore della proprietà per $10,000 (numerico)
#' \item \code{ptratio} rapport allievo insegnante per centro urbano (numerico)
#' \item \code{black} 1000(Bk - 0.63)^2 dove Bk è la proporzione di isolati per centro urbano (numerico)
#' \item \code{lstat} stato economicamente inferiore della popolazione (percentuale)  (numerico)
#' \item \code{medv} valore mediano delle case occupate dai proprietari in migliaia di dollari (numerico)
#' }
#' @source Questo dataset è disponibile pubblicamente per ricerca presso \href{http://lib.stat.cmu.edu/datasets/boston}{UCI Machine Learning repository}.
#'
NULL
##################################################################################################################################


##################################################################################################################################
#' Default di clienti di carte di credito
#' 
#' 
#' @name default
#' 
#' 
#' @description I dati di \code{default} contengono informazioni sui default di pagamento di clienti a Taiwan.
#' 
#'  
#' @usage data(default)
#' 
#' 
#' @format \code{default} è un data frame tbl con 30000 osservazioni su 25 variabili.
#' 
#' 
#' @details 
#' Le 25 variabili del \code{default} data frame tbl sono:
#' \itemize{
#' \item \code{ID} (numeric);
#' \item \code{LIMIT_BAL} Ammontare del credito (dollari d Taiwan): include sia il credito del singolo cliente consumer sia quello della sua famiglia (supplementare) (numerico)
#' \item \code{SEX} Sesso (fattore con 2 livelli: \code{1} (Male) e \code{2}(Female));
#' \item \code{EDUCATION} Livello di formazione (fattore con 7 livelli: \code{0}, \code{1}, \code{2}, \code{3}, \code{4}, \code{5} e \code{6});
#' \item \code{MARRIAGE} Stato coniugale (fattore con 4 livelli: \code{0}, \code{1}, \code{2} e \code{3});
#' \item \code{AGE} Età (anni) (numerico);
#' \item \code{PAY_0} Storia dei pagamenti passati: stato di rimborso a settembre, 2005 (numerico);
#' \item \code{PAY_2} Storia dei pagamenti passati: stato di rimborso in agosto, 2005 (numerico);
#' \item \code{PAY_3} Storia dei pagamenti passati: stato di rimborso in luglio, 2005 (numerico);
#' \item \code{PAY_4} Storia dei pagamenti passati: stato di rimborso in giugno, 2005 (numerico);
#' \item \code{PAY_5} Storia dei pagamenti passati: stato di rimborso in maggio, 2005 (numerico);
#' \item \code{PAY_6} Storia dei pagamenti passati: stato di rimborso in aprile, 2005 (numerico);
#' \item \code{BILL_AMT1} Ammontare del conto (dollari Taiwanesi): ammontare del conto a settembre, 2005 (numerico);
#' \item \code{BILL_AMT2} Ammontare del conto (dollari Taiwanesi): ammontare del conto in agosto, 2005 (numerico);
#' \item \code{BILL_AMT3} Ammontare del conto (dollari Taiwanesi): ammontare del conto in luglio, 2005 (numerico);
#' \item \code{BILL_AMT4} Ammontare del conto (dollari Taiwanesi): ammontare del conto in giugno, 2005 (numerico);
#' \item \code{BILL_AMT5} Ammontare del conto (dollari Taiwanesi): ammontare del conto in maggio, 2005 (numerico);
#' \item \code{BILL_AMT6} Ammontare del conto (dollari Taiwanesi): ammontare del conto in aprile, 2005 (numerico);
#' \item \code{PAY_AMT1} Ammontare del pagamento precedente (dollari Taiwanesi): ammontare pagato a settembre (numerico);
#' \item \code{PAY_AMT2} Ammontare del pagamento precedente (dollari Taiwanesi): ammontare pagato in agosto (numerico);
#' \item \code{PAY_AMT3} Ammontare del pagamento precedente (dollari Taiwanesi): ammontare pagato in luglio (numerico);
#' \item \code{PAY_AMT4} Ammontare del pagamento precedente (dollari Taiwanesi): ammontare pagato in giugno (numerico);
#' \item \code{PAY_AMT5} Ammontare del pagamento precedente (dollari Taiwanesi): ammontare pagato in maggio (numerico);
#' \item \code{PAY_AMT6} Ammontare del pagamento precedente (dollari Taiwanesi): ammontare pagato in aprile (numerico);
#' \item \code{default_payment} default di pagamento il prossimo mese (fattore con 2 livelli: \code{0} (No) e \code{1} (Yes));
#' }
#' 
#' Per cortesia includete questa citazione se pensate di usare questo dataset:\cr
#' Yeh, I. C., & Lien, C. H. (2009). The comparisons of data mining techniques for the predictive accuracy of probability of default of credit card clients. Expert Systems with Applications, 36(2), 2473-2480.
#' Dati disponibili all'indirizzo \url{https://archive.ics.uci.edu/ml/datasets/default+of+credit+card+clients}.
#' @source I-Cheng Yeh, Department of Information Management, Chung Hua University, Taiwan. (2) Department of Civil Engineering, Tamkang University, Taiwan.
NULL
##################################################################################################################################


##################################################################################################################################
#' Registrazioni di Pazienti con Diabete
#' 
#' 
#' @name diabetes
#' 
#' 
#' @description Dati Insulin Dependent Diabetes Mellitus (IDDM) per l'AAAI Spring Symposium (1994).
#' 
#'  
#' @usage data(diabetes)
#' 
#' 
#' @format \code{diabetes} è un data frame tbl con 30264 osservazioni su 5 variabili.
#' 
#' 
#' @details 
#' Le registrazioni sui pazienti affetti da diebete sono state ottenute a partire da due fonti: un dispositivo elettronico di registrazione automatica e registrazioni su carta. Il dispositivo automatico aveva un orologio interno per marcare gli eventi, mentre le registrazioni su carta fornivano solo slot di "istanti logici" (colazione, pranzo, cena, sonno). Per le registrazioni su carta, sono stati assegnati orari fissati alla colazione (08:00), al pranzo (12:00), alla cena (18:00), e al sonno (22:00). Di conseguenza le registrazioni su carta hanno tempi fittiziamente uniformi mentre le registrazioni elettronico hanno tempi più realistici. 
#' 
#' I dati contengono cinque variabili:
#' \itemize{
#' \item \code{patient} id (character), questo corrisponde a un file sui dati originali
#' \item \code{date} in formato MM-DD-YYYY (fattore)
#' \item \code{time} in formato XX:YY  (fattore)
#' \item \code{code} indica un task, secondo la lista che segue  (integer)
  #' \itemize{  
  #' \item 33 = Dose di insulina "standard"
  #' \item 34 = Dose di insulina NPH
  #' \item 35 = Dose di insulina UltraLente
  #' \item 48 = Misurazione di glucosio nel sangue non specificata
  #' \item 57 = Misurazione di glucosio nel sangue non specificata
  #' \item 58 = Misurazione di glucosio nel sangue pre-colazione
  #' \item 59 = Misurazione di glucosio nel sangue post-colazione
  #' \item 60 = Misurazione di glucosio nel sangue pre-pranzo
  #' \item 61 = Misurazione di glucosio nel sangue post-pranzo
  #' \item 62 = Misurazione di glucosio nel sangue pre-cena
  #' \item 63 = Misurazione di glucosio nel sangue post-cena
  #' \item 64 = Misurazione di glucosio nel sangue pre-snack
  #' \item 65 = Sintomi di ipoglicemia
  #' \item 66 = Ingestione di pasto tipica
  #' \item 67 = Ingestione di pasto più abbondante
  #' \item 68 = Ingestione di pasto più scarso
  #' \item 69 = Attività di esercizio tipica
  #' \item 70 = Attività di esercizio più intensa
  #' \item 71 = Attività di esercizio più scarsa
  #' \item 72 = Evento speciale non identificato
#' }
#' \item \code{value} valore di insulina (character)
#' }
#' 
#' @source Questo dataset è disponibile pubblicamente all'indirizzo \href{http://archive.ics.uci.edu/ml/datasets/Diabetes}{UCI Machine Learning repository}.
NULL
##################################################################################################################################


##################################################################################################################################
#' Correlazioni Uso Sostanze Alteranti 
#' 
#' 
#' @name druguse
#' 
#' 
#' @description I dati \code{druguse} contengono la matrice di correlazione tra tassi d'uso (registrati su una scala a 5 punti)
#' per un campione di 1634 studenti tra la settima e la nona classe in 11 scuole della grande area metropolitana di 
#' Los Angeles. Ogni partecipante ha compilato un questionario sul numero di volte in cui ha fatto uso dei diversi tipi di sostanza.
#' 
#'  
#' @usage data(druguse)
#' 
#' 
#' @format \code{druguse} è una matrice di correlazione 13 x 13.
#' 
#' 
#' @details 
#' Le 13 sostanze di cui è stato richiesto l'uso, che sono anche i nomi di riga e di colonna della matrice, sono:
#' \itemize{
#' \item \code{cigarettes} sigarette;
#' \item \code{beer} birra;
#' \item \code{wine} vino;
#' \item \code{liquor} liquore;
#' \item \code{cocaine} cocaina;
#' \item \code{tranquillizers} tranquillanti;
#' \item \code{drug store medications} farmaci da banco usati per sostenersi;
#' \item \code{heroin} ed altri oppiacei;
#' \item \code{marijuana} mariuana;
#' \item \code{hashish} hashish;
#' \item \code{inhalants} (golla, benzine, ecc.);
#' \item \code{hallucinogenics} (LSD, mescalina, ecc.);
#' \item \code{amphetamine} stimolanti.
#' }
#' 
#' 
#' @source Everitt, B. and Hothorn, T., *An Introduction to Applied Multivariate Analysis with `R`*, Springer, 2011; da Huba, G. J., Wingard, J., and Bentler, P. (1981), “A comparison of two latent variable causal models for adolescent drug use,” Journal of Personality and Social Psychology, 40, 180–193. Cited on p. 151, 211, 216.
NULL
##################################################################################################################################


##################################################################################################################################
#' CEO Più Pagati negli U.S.A. 
#' 
#' 
#' @name forbes94
#' 
#' 
#' @description I dati \code{forbes94} riguardano i compensi ottenuti nel 1994 dagli 800 CEO più pagati negli USA
#' (Questo dataset proviene da una classifica pubblicata dala rivista Forbes nello stesso anno).
#' 
#'  
#' @usage data(forbes94)
#' 
#' 
#' @format \code{forbes94} è un data frame tbl con 800 osservazioni su 30 variabili.
#' 
#' 
#' @details 
#' Le 30 variabili del data frame tbl \code{forbes94} sono le seguenti:
#' \itemize{
#' \item \code{TotalComp} (numerico)
#' \item \code{WideIndustry} fattore con 19 livelli
#' \item \code{Company} fattore con 800 livelli
#' \item \code{CEO} fattore con 796 livelli
#' \item \code{CityofBirth} fattore con 402 livelli
#' \item \code{StateofBirth} fattore con 51 livelli
#' \item \code{Age} (numerico)
#' \item \code{Undergrad} fattore con 262 livelli
#' \item \code{UGDegree} fattore con 25 livelli
#' \item \code{UGDate} (numerico)
#' \item \code{AgeOfUnder} (numerico)
#' \item \code{Graduate} fattore con 129 livelli
#' \item \code{GradDegree} fattore con 20 livelli
#' \item \code{MBA} (numerico)
#' \item \code{MasterPhd} (numerico)
#' \item \code{G_date} (numerico)
#' \item \code{AgeOfGradu} (numerico)
#' \item \code{YearsFirm} (numerico)
#' \item \code{YearsCEO} (numerico)
#' \item \code{Salary} (numerico)
#' \item \code{Bonus} (numerico)
#' \item \code{Other} (numerico)
#' \item \code{StGains} (numerico)
#' \item \code{Compfor5Yrs} (numerico)
#' \item \code{StockOwned} (numerico)
#' \item \code{Sales} (numerico)
#' \item \code{Profits} (numerico)
#' \item \code{ReturnOver5Yrs} (numerico)
#' \item \code{Industry} (numerico)
#' \item \code{IndustryCode} (numerico)
#' }
NULL
##################################################################################################################################


##################################################################################################################################
#' G1res
#' 
#' 
#' @name g1res
#' 
#' 
#' @description The \code{g1res} data was ......
#' 
#'  
#' @usage data(g1res)
#' 
#' 
#' @format \code{g1res} è un data frame tbl con 19 osservazioni su 3 variabili.
#' 
#' 
#' @details 
#' The 3 variabili del data frame tbl \code{g1res} sono:
#' \itemize{
#' \item \code{V1} (numeric);
#' \item \code{V2} (numeric);
#' \item \code{V3} (numeric).
#' }
NULL
##################################################################################################################################


##################################################################################################################################
#' Carte di Credito in Germania
#' 
#' 
#' @name german
#' @aliases germannumeric germanstring
#' 
#' 
#' @description I dati \code{german} contengono informazioni su un campione di 1000 clienti che hanno ottenuto una carta di creditp. Alcuni di questi
#' non hanno pagato (classe Bad) ed altri sì (Good). Sono state misurate altre 20 caratteristiche su di essi o sulle loro carte di credito. 
#' 
#'  
#' @usage data(german)
#' 
#' 
#' @format \code{german} è un data frame tbl con 1000 osservazioni su 21 variabili.
#' 
#' 
#' @details 
#' Le 21 variabili del data frame tbl \code{german} sono:
#' \itemize{
#' \item \code{StatusAccount} fattore con 4 livelli
#' \item \code{Duration} (numerico)
#' \item \code{CreditHistory} fattore con 5 livelli
#' \item \code{Purpose} fattore con 10 livelli
#' \item \code{CreditAmount} (numerico)
#' \item \code{SavingsAccountBonds} fattore con 5 livelli
#' \item \code{EmployedSince} fattore con 5 livelli
#' \item \code{RatePercIncome} (numerico)
#' \item \code{StatusAndSex} fattore con 5 livelli
#' \item \code{OtherBebtorsGarants} fattore con 3 livelli
#' \item \code{ResidenceSince} (numerico)
#' \item \code{Property} fattore con 4 livelli
#' \item \code{AgeYears} (numerico)
#' \item \code{OtherInstallPlans} fattore con 3 livelli
#' \item \code{Housing} fattore con 3 livelli
#' \item \code{NumberOfCredits} (numerico)
#' \item \code{Job} fattore con 4 livelli
#' \item \code{NumberPeopleMaintained} (numerico)
#' \item \code{Telephone} fattore con 2 livelli
#' \item \code{ForeignWorker} fattore con 2 livelli
#' \item \code{Class} fattore con 2 livelli
#' }
#' 
#' @source Questo dataset è disponibile pubblicamente all'indirizzo \href{https://archive.ics.uci.edu/ml/datasets/statlog+(german+credit+data)}{UCI Machine Learning repository}.


##################################################################################################################################


##################################################################################################################################
#' Vita Attesa
#' 
#' 
#' @name life
#' 
#' 
#' @description I dati \code{life} contengono valori di vita attesa alla nascita, 25, 50 e 75 anni per uomini e donne in 31 paesi o regioni.
#' 
#'  
#' @usage data(life)
#' 
#' 
#' @format \code{life} è un data frame tbl con 31 osservazioni su 9 variabili.
#' 
#' 
#' @details 
#' Le 9 variabili del data frame tbl \code{life} sono:
#' \itemize{
#' \item \code{country} (character);
#' \item \code{m0} vita attesa in anni per maschi alla mascita (numerico);
#' \item \code{m25} vita attesa in anni per maschi a 25 anni (numerico);
#' \item \code{m50} vita attesa in anni per maschi a 50 anni (numerico);
#' \item \code{m75} vita attesa in anni per maschi a 75 anni (numerico);
#' \item \code{m0} vita attesa in anni per donne alla mascita (numerico);
#' \item \code{m25} vita attesa in anni per donne a 25 anni (numerico);
#' \item \code{m50} vita attesa in anni per donne a 50 anni (numerico);
#' \item \code{m75} vita attesa in anni per donne a 75 anni (numerico).
#' }
#' 
#' Il dataset è stato modificato per un possibile valore di vita attesa errato 
#' 
#' @source Everitt, B. and Hothorn, T., An Introduction to Applied Multivariate Analysis with R, Springer, 2011; da: Keyfitz, N. and Flieger, W. (1971), Population: Facts and Methods of Demography, San Francisco, CA: W.H. Freeman
NULL
##################################################################################################################################


##################################################################################################################################
#' Dati sui Comuni Italiani
#' 
#' 
#' @name italia
#' 
#' 
#' @description Il dataset \code{italia} contiene informazioni sugli 8003 comuni italiani al 2016-01-01. 
#' In particolare, sono anche didponibili informaizoni su "province", "regioni, "ripartizioni".
#' 
#'  
#' @usage data(italia) 
#' 
#' 
#' @format \code{italia} è un data frame tbl con 8003 osservazioni su 14 variabili.
#' 
#' 
#' @details 
#' Le 14 variabili del data frame tbl \code{italia} sono:
#' \itemize{
#' \item \code{cod_comune} codici dei comuni (character);
#' \item \code{comune} nomi dei comuni (character);
#' \item \code{comune_cap_prov} se il comune è un capoloogo di provincia (logical);
#' \item \code{pop_legale} popolazione residente nel comune alla data dell'ultimo censimento (2011-10-09) (integer);
#' \item \code{progr_comune} codice progressivo dei comuni italiani (ricomincia da 1 per ogni provincia) (character);
#' \item \code{cod_provincia} codice della provincia; si noti che \code{cod_comune} è \code{cod_provincia} concatenato con \code{progr_comune} (character);
#' \item \code{provincia} nomi delle province (character);
#' \item \code{sigla_auto} sigla della provincia (targa automobilistica) (character);
#' \item \code{cod_citta_metro} codici delle città metropolitane (character);
#' \item \code{citta_metro} nomi delle città metropolitane (character);
#' \item \code{cod_regione} codici delle regioni (character);
#' \item \code{regione} nomi delle regioni (character);
#' \item \code{cod_rip_geo} codici delle ripartizioni geografiche (character);
#' \item \code{rip_geo} nomi delle ripartizioni geografiche (character).
#' }
#' 
#' 
#' @source Questo dataset proviene dal sito dell'Istat: \href{http://www.istat.it/it/archivio/6789}{Istituto nazionale di statistica (Istat)}.
NULL
##################################################################################################################################

##################################################################################################################################
#' Dati sui Comuni Italiani
#' 
#' 
#' @name comuni
#' 
#' 
#' @description Il dataset \code{comuni} contiene informazioni sugli 8003 comuni italiani al 2016-01-01. 
#' In particolare, sono anche didponibili informaizoni su "province", "regioni, "ripartizioni".
#' 
#'  
#' @usage data(comuni) 
#' 
#' 
#' @format \code{comuni} è un data frame tbl con 8003 osservazioni su 9 variabili.
#' 
#' 
#' @details 
#' Le 9 variabili del data frame tbl \code{comuni} sono:
#' \itemize{
#' \item \code{cod_comune} codici dei comuni (character);
#' \item \code{comune} nomi dei comuni (character);
#' \item \code{comune_cap_prov} se il comune è un capoloogo di provincia (logical);
#' \item \code{pop_legale} popolazione residente nel comune alla data dell'ultimo censimento (2011-10-09) (integer);
#' \item \code{progr_comune} codice progressivo dei comuni italiani (ricomincia da 1 per ogni provincia) (character);
#' \item \code{cod_provincia} codice della provincia; si noti che \code{cod_comune} è \code{cod_provincia} concatenato con \code{progr_comune} (character);
#' \item \code{cod_citta_metro} codici delle città metropolitane (character);
#' \item \code{cod_regione} codici delle regioni (character);
#' \item \code{cod_rip_geo} codici delle ripartizioni geografiche (character);
#' }
#' 
#' 
#' @source Questo dataset proviene dal sito dell'Istat: \href{http://www.istat.it/it/archivio/6789}{Istituto nazionale di statistica (Istat)}.
NULL
##################################################################################################################################

##################################################################################################################################
#' Dati sulle Province Italiane
#' 
#' 
#' @name province
#' 
#' 
#' @description Il dataset \code{province} contiene informazioni sulle 110 province e città metropolitane italiane al 2016-01-01. 
#' 
#'  
#' @usage data(province) 
#' 
#' 
#' @format \code{province} è un data frame tbl con 110 osservazioni su 5 variabili.
#'  
#' 
#' @details 
#' Le 5 variabili del data frame tbl \code{province} sono:
#' \itemize{
#' \item \code{cod_provincia} codici delle province italiane; 
#' \item \code{provincia} nomi delle province italiane (character);
#' \item \code{sigla_auto} targa automobilistica delle province italiane (character);
#' \item \code{cod_citta_metro} codici delle città metropolitane italiane (character);
#' \item \code{citta_metro} nomi delle città metropolitane (character);
#' }
#' 
#' 
#' @source Questo dataset proviene dal sito dell'Istat: \href{http://www.istat.it/it/archivio/6789}{Istituto nazionale di statistica (Istat)}.
NULL
##################################################################################################################################

##################################################################################################################################
#' Dati sulle Regioni Italiane
#' 
#' @name regioni
#' 
#' @description Il dataset \code{regioni} contiene informazioni sulle 20 regioni italiane al 2016-01-01.
#' 
#' @usage data(regioni) 
#' 
#' @format \code{regioni} è un data frame tbl con 20 osservazioni su 2 variabili.
#' 
#' @details 
#' Le 2 variabili del data frame tbl \code{regioni} sono:
#' \itemize{
#' \item \code{cod_regione} codici delle regioni italiane (character);
#' \item \code{regione} nomi delle regioni italiane (character);
#' }
#' 
#' 
#' @source Questo dataset proviene dal sito dell'Istat: \href{http://www.istat.it/it/archivio/6789}{Istituto nazionale di statistica (Istat)}.
NULL
##################################################################################################################################

##################################################################################################################################
#' Dati sulle Ripartizioni Italiane
#' 
#' 
#' @name ripartizioni
#' 
#' 
#' @description Il dataset \code{ripartizioni} contiene informazioni sulle 5 ripartizioni italiane al 2016-01-01. 
#'  
#' @usage data(ripartizioni) 
#' 
#' 
#' @format \code{ripartizioni} è un data frame tbl con 5 osservazioni su 2 variabili. 
#' 
#' 
#' @details 
#' Le 2 variabili del data frame tbl \code{ripartizioni} sono:
#' \itemize{
#' \item \code{cod_rip_geo} codici delle ripartizioni geografiche italiane (character);
#' \item \code{rip_geo} nomi delle ripartizioni geografiche italiane (character).
#' }
#' 
#' 
#' @source Questo dataset proviene dal sito dell'Istat: \href{http://www.istat.it/it/archivio/6789}{Istituto nazionale di statistica (Istat)}.
NULL
##################################################################################################################################


##################################################################################################################################
#' Dati fittizi per MDS 
#' 
#' 
#' @name mds
#' 
#' 
#' @description Il dataset \code{mds} è fittizio e contiene 10 osservazioni su 5 variabili numeriche.
#' 
#'  
#' @usage data(mds)
#' 
#' 
#' @format \code{mds} è un data frame tbl con 10 osservazioni su 5 variabili
#' 
#' 
#' @details 
#' Le 5 variabili del data frame tbl \code{mds} sono:
#' \itemize{
#' \item \code{V1} (numerico);
#' \item \code{V2} (numerico);
#' \item \code{V3} (numerico);
#' \item \code{V4} (numerico);
#' \item \code{V5} (numerico);
#' }
NULL
##################################################################################################################################


##################################################################################################################################
#' Test Automobili su Strada  
#' 
#' 
#' @name mtcars
#' 
#' 
#' @description I dati di \code{mtcars} sono un estratto dell'analogo data frame del package \code{datasets}, incluso nella distribuzione base di \code{R}.
#' 
#'  
#' @usage data(mtcars)
#' 
#' 
#' @format \code{mtcars} è un data frame tbl con 32 osservazioni su 5 variabili.
#' 
#' 
#' @details 
#' Le 5 variabili del data frame tbl \code{mtcars} sono:
#' \itemize{
#' \item \code{car} modello d'auto (character);
#' \item \code{carb} numero di carburatori (numerico);
#' \item \code{cyl} numero di cilindri (numerico);
#' \item \code{mpg} miglia per gallone (numerico);
#' \item \code{disp} cilindrata (pollici cubi) (numerico).
#' }
#' 
#' 
#' @seealso la pagina di help completa di \code{mtcars} si trova nel package \code{datasets}: \code{\link[datasets]{mtcars}}
NULL
##################################################################################################################################


##################################################################################################################################
#' Peso e Altezza di 300 Persone Italiane
#' 
#' 
#' @name people
#' 
#' 
#' @description Il dataset \code{people} contiene informazioni su 300 Italiani: sesso, area geografica di provenienza, peso e altezza.
#' 
#'  
#' @usage data(people)
#' 
#' 
#' @format \code{people} è un data frame tbl con 300 osservazioni su 4 variabili.
#' 
#' 
#' @details 
#' Le 4 variabili del data frame tbl \code{people} sono:
#' \itemize{
#' \item \code{Gender} gender (fattore con 2 livelli: Female, Male);
#' \item \code{Area} area di residenza (fattore con 4 livelli: Centro, Isole, Nord, Sud);
#' \item \code{Weight} peso in kg (numerico);
#' \item \code{Height} altezza in cm (numerico).
#' }
NULL
##################################################################################################################################


##################################################################################################################################
#' Diabete nella Popolazione Indiana
#' 
#' 
#' @name pimaindiansdiabetes2
#' 
#' 
#' @description I dati di \code{pimaindiansdiabetes2} contengono informazioni sul diabete nella popolazione indiana.
#' 
#'  
#' @usage data(pimaindiansdiabetes2)
#' 
#' 
#' @format \code{pimaindiansdiabetes2} è un data frame tbl con 768 osservazioni su 9 variabili.
#' 
#' 
#' @details 
#' Le 9 variabili del data frame tbl \code{pimaindiansdiabetes2} sono:
#' \itemize{
#' \item \code{pregnant} Numero di gravidanze (numerico);
#' \item \code{glucose} Concentrazione di glucosio plasmatico a 2 ore in un test di tolleranza al glucosio orale (numerico);
#' \item \code{pressure} Pressione sanguigna diastolica (mm Hg) (numerico);
#' \item \code{triceps} Spessore della pelle nella piega del tricipite (mm) (numerico);
#' \item \code{insulin} Insulina sierica a 2 ore (mu U/ml)(numerico);
#' \item \code{mass} Indice di massa corporea ((peso in kg)/(altezza in m)^2) (numerico);
#' \item \code{pedigree} Funzione dell'albero genealogico del diabete (numerico);
#' \item \code{age} Età (anni) (numerico);
#' \item \code{diabetes} variabile categoriale: diabetico o no (fattore con 2 livelli: \code{neg} o \code{pos});
#' }
#' 
#' @source National Institute of Diabetes and Digestive and Kidney Diseases; disponibile anche dal package \code{mlbench}
NULL
##################################################################################################################################


##################################################################################################################################
#' Cancro alla Prostata
#' 
#' 
#' @name prostate
#' 
#' 
#' @description I dati di \code{prostate} derivano da uno studio che analizzava la correlazione tra il livello di uno specifico antigene della prostata ad un numero di valori clinici in uomini che stavano per subire una prostatectomia radicale
#' 
#'  
#' @usage data(prostate)
#' 
#' 
#' @format \code{prostate} è un data frame tbl con 97 osservazioni su 9 variabili.
#' 
#' 
#' @details 
#' Le 9 variabili del data frame tbl \code{prostate} sono:
#' \itemize{
#' \item \code{lcavol} log(volume cancro) (numerico);
#' \item \code{lweight} log(peso prostata) (numerico);
#' \item \code{age} Età (numerico);
#' \item \code{lbph} log(ammontare di iperplasia prostatica benigna) (numerico);
#' \item \code{svi} invasione della vescica seminale (numerico);
#' \item \code{lcp} log(penetrazione capsulare) (numerico);
#' \item \code{gleason} Punteggio Gleason (numerico);
#' \item \code{pgg45} Percentuale di punteggio Gleason 4 o 5 (numerico);
#' \item \code{lpsa} log(antigene specifico della prostata) (numerico);
#' }
#' 
#' @source Stamey, T.A., Kabalin, J.N., McNeal, J.E., Johnstone, I.M., Freiha, F., Redwine, E.A. and Yang, N. (1989)
#' Prostate specific antigen in the diagnosis and treatment of adenocarcinoma of the prostate: II. radical prostatectomy treated patients, Journal of Urology 141(5), 1076–1083.
#' Disponibile anche dal package \code{lasso2}
NULL
##################################################################################################################################


##################################################################################################################################
#' Sres 
#' 
#' 
#' @name sres
#' 
#' 
#' @description I dati \code{sres} sono .....
#' 
#'  
#' @usage data(sres)
#' 
#' 
#' @format \code{sres} è un data frame tbl con 19 osservzioni su 3 variabili.
#' 
#' 
#' @details 
#' Le 3 variabili del data frame tbl \code{sres} sono:
#' \itemize{
#' \item \code{V1} (numeric);
#' \item \code{V2} (numeric);
#' \item \code{V3} (numeric).
#' }
NULL
##################################################################################################################################


##################################################################################################################################
#' 79 Aziende negli U.S.A.
#' 
#' 
#' @name uscompanies
#' 
#' 
#' @description I dati di \code{uscompanies} contengono informazioni su 79 aziende U.S.A. classificate rispetto a 6 caratteristiche numeriche (risorse, vendite, ecc.)
#' e una caratteristica categoriale (settore industriale); \code{indshort} è anche una abbreviazione di \code{industry}.
#' 
#'  
#' @usage data(uscompanies)
#' 
#' 
#' @format \code{uscompanies} è un data frame tbl con 79 osservazioni su 9 variabili
#' 
#' 
#' @details 
#' Le 9 variabili del data frame tbl \code{uscompanies} sono:
#' \itemize{
#' \item \code{company} azienda (fattore);
#' \item \code{assets} risore (USD) (integer);
#' \item \code{sales} vendite (USD) (integer);
#' \item \code{value} valore di mercato (USD) (integer);
#' \item \code{profits} profitti (USD) (numerico);
#' \item \code{cashflow} flusso di cassa (USD) (numerico);
#' \item \code{employees} impiegati (numerico);
#' \item \code{industry} settore industriale (fattore);
#' \item \code{indshort} settore industriale in una classificazione meno fine (fattore);
#' }
#' 
#' 
#' @source Härdle and Simar, Applied Multivariate Statistical Analysis, 3rd ed., Springer, 2012
NULL
##################################################################################################################################


##################################################################################################################################
#' Tassi di Criminalità negli U.S.A.
#' 
#' 
#' @name uscrime
#' 
#' 
#' @description I dati di \code{uscrime} contengono informazioni su tassi di criminalità (numero di crimini per 100,000 residenti) nei 50 stati U.S.A.;
#' il dataset include anche l'estensione del territorio e la popolazione (nel 1985) dei 50 stati U.S.A.; i reati sono classificati seguendo queste sette categorie:
#' murder (assassinio, omocidio), rape (stupro), robbery (rapina), assault (aggressione), burglary (furto con scasso), larceny (furto) e auto-theft (furto d'auto.
#' 
#'  
#' @usage data(uscrime)
#' 
#' 
#' @format \code{uscrime} è un data frame tbl con 50 osservazioni su 12 variabili.
#' 
#' 
#' @details 
#' Le 12 variabili del data frame tbl \code{uscrime} sono:
#' \itemize{
#' \item \code{state} abbreviazione del nome dello stato U.S.A. (character);
#' \item \code{land} area della superficie (integer);
#' \item \code{popu1985} popolazione nel 1985 (integer);
#' \item \code{murd} number of omicidi per 100,000 residenti (numerico);
#' \item \code{rape} number of stupri per 100,000 rresidenti (numerico);
#' \item \code{robb} number of rapine per 100,000 residenti (numerico);
#' \item \code{assa} number of aggressioni per 100,000 residenti (numerico);
#' \item \code{burg} number of furti con scasso per 100,000 residenti (numerico);
#' \item \code{larc} number of furti per 100,000 residenti (numerico);
#' \item \code{auto} number of furti d'auto per 100,000 residenti (numerico);
#' \item \code{reg} numero di regione degli stati U.S.A. (integer);
#' \item \code{div} numero di divisione degli stati U.S.A. (integer).
#' }
#' 
#' 
# #' @source Härdle, W. K. and Simar, L., Applied Multivariate Statistical Analysis, 3rd edition, Springer, 2012
NULL
##################################################################################################################################


##################################################################################################################################
#' 22 Società energetiche negli U.S.A.
#' 
#' 
#' @name utilities
#' 
#' 
#' @description I dati di \code{utilities} contengono dati di 22 società U.S.A. classificate rispetto 8 caratteristiche numeriche (copertura, rendimento, costo, ecc.).
#' 
#'  
#' @usage data(utilities)
#' 
#' 
#' @format \code{utilities} è un data frame tbl con 22 osservazioni su 10 variabili.
#' 
#' 
#' @details 
#' Le 10 variabili del data frame tbl \code{utilities} sono:
#' \itemize{
#' 
#' \item \code{coverage} capacità di rimborso (reddito/debito) (numerico);
#' \item \code{return} tasso di remunerazione del capitale (numerico);
#' \item \code{cost} costo per kW di capacità in atto (integer);
#' \item \code{load} fattore di carico annuale (numerico);
#' \item \code{peak} crescita della domanda di picco in kWh dal 1974 al 1975 (numerico);
#' \item \code{sales} vendite (kWh si uso all'anno) (integer);
#' \item \code{nuclear} percentuale nucleare (numerico);
#' \item \code{fuel} costo totale per combustibile (centesimi per kWh) (numerico);
#' \item \code{company} nome completo della società (character);
#' \item \code{comp_short} nome breve della società (character).
#' }
NULL
##################################################################################################################################


##################################################################################################################################
#' Informazioni Topografiche sul Vulcano Maunga Whau, Auckland
#' 
#' 
#' @name volcano3d
#' 
#' 
#' @description I dati di \code{volcano3d} sono derivati dal data frame \code{volcano} incluso nella distribuione base di \code{R},
#' e ritornano informazioni topografiche su Maunga Whau, uno dei circa 50 vulcani nell'area vulcanica di Auckland, su una griglia 10m per 10m. 
#' 
#'  
#' @usage data(volcano3d)
#' 
#' 
#' @format \code{volcano3d} è un data frame tbl con 5307 osservazioni su 3 variabili.
#' 
#' 
#' @details 
#' Le 3 variabili del data frame tbl \code{volcano3d} sono:
#' \itemize{
#' \item \code{x} posizione x (numerico)
#' \item \code{y} posizione y (numerico)
#' \item \code{z} posizione z (numerico)
#' }
#' 
#' 
#' @seealso la pagina di help di \code{volcano} del package \code{datasets}: \code{\link[datasets]{volcano}}
NULL
##################################################################################################################################


##################################################################################################################################
#' Dati Meteorologici Giornalieri a Canberra
#' 
#' 
#' @name wea
#' 
#' 
#' @description I dati di \code{wea} contengono dati meteorologici giornalieri (temperatura, pioggia, vento, ectc.) a Canberra, Australia,
#' dal 2007-11-01 al 2008-10-31.
#' 
#'  
#' @usage data(wea)
#' 
#' 
#' @format \code{wea} è un data frame tbl con 366 osservazioni su 24 variabili.
#' 
#' 
#' @details 
#' Le 24 variabili del data frame tbl \code{wea} sono:
#' \itemize{
#' \item \code{Date} (Data), formato: "2007-11-01" "2007-11-02" "2007-11-03" "2007-11-04" ...
#' \item \code{Location} fattore con 49 livelli, ma un solo valore: Camberra
#' \item \code{MinTemp} temepratura minima (numerico)
#' \item \code{MaxTemp} temepratura massima (numerico)
#' \item \code{Rainfall} pioggia (numerico)
#' \item \code{Evaporation} evaporazione (numerico)
#' \item \code{Sunshine} lucce solare (numerico)
#' \item \code{WindGustDir} direzione raffica di vento; fattore ordinato con 16 livelli
#' \item \code{WindGustSpeed} velocità raffica di vento (numerico)
#' \item \code{WindDir9am} direzione vento alle 9am; fattore ordinato con 16 livelli
#' \item \code{WindDir3pm} direzione vento alle 3pm; fattore ordinato con 16 livelli
#' \item \code{WindSpeed9am} velocità vento alle 9am (numerico)
#' \item \code{WindSpeed3pm} velocità vento alle 3pm (numerico)
#' \item \code{Humidity9am} umidità alle 9am (numerico)
#' \item \code{Humidity3pm} umidità alle 3pm (numerico)
#' \item \code{Pressure9am} pressione alle 9am (numerico)
#' \item \code{Pressure3pm} pressione alle 3pm (numerico)
#' \item \code{Cloud9am} nuvolosità alle 9am (numerico)
#' \item \code{Cloud3pm} nuvolosità alle 3pm (numerico)
#' \item \code{Temp9am} temperatura alle 9am (numerico)
#' \item \code{Temp3pm} temperatura alle 3pm (numerico)
#' \item \code{RainToday} pioggia oggi; fattore con 2 livelli: No, Yes
#' \item \code{RISK_MM} quantità di pioggia del giorno succesivo (numeric)
#' \item \code{RainTomorrow} pioggia domani; fattore con 2 livelli: No, Yes
#' }
#' 
#' @source \href{http://www.bom.gov.au/climate/dwo/}{Australian Bureau of Meteorology’s Website}

##################################################################################################################################


##################################################################################################################################
#' Vini Italiani del Piemonte, Italia
#' 
#' 
#' @name wines
#' 
#' 
#' @description I dati \code{wines} sono stati estratti dall'analogo data frame del package \code{kohonen} e contengono informazione
#' su un insieme di 177 campioni di vino italiani di 3 diversi tipi di vite; sono state misurate 13 variabili (alcool, acido malico, ecc.).
#' 
#'  
#' @usage data(wines)
#' 
#' 
#' @format \code{wines} è un data frame tbl con 177 osservazioni su 13 variabili.
#' 
#' 
#' @details 
#' Le 13 variabili del data frame tbl \code{wines} sono:
#' \itemize{
#' \item \code{alcohol} alcool (numerico)
#' \item \code{malic.acid} acido malico (numerico)
#' \item \code{ash} ceneri (numerico)
#' \item \code{ash.alkalinity} alcanilità ceneri (numerico)
#' \item \code{magnesium} magnesio (numerico)
#' \item \code{tot..phenols} totale fenoli (numerico)
#' \item \code{flavonoids} flavonoidi (numerico)
#' \item \code{non.flav..phenols} fenoli non flavonoidi (numerico)
#' \item \code{proanth} proantocianine (numerico)
#' \item \code{col..int.} intensità colore (numerico)
#' \item \code{col..hue} sfumature colore (numerico)
#' \item \code{OD.ratio} OD280/OD315 di vini diluiti (numerico)
#' \item \code{proline} prolina (numerico)
#' \item \code{vintages} fattore con 3 livelli: Barolo, Grignolino, Barbera
#' \item \code{wine.classes} classi di vino (numerico)
#' }
#' 
#' 
#' @seealso la pagina di help completa su \code{wines} del package \code{kohonen}: \code{\link[kohonen]{wines}}
NULL
##################################################################################################################################


##################################################################################################################################
#' Tornei di Wimbledon
#' 
#' 
#' @name wimbledon
#' 
#' 
#' @description Il dataset \code{wimbledon} contiene informazioni sulle finali maschili di Wimbledon dal 1968 al 2015.
#'  
#' @usage data(wimbledon)
#' 
#' 
#' @format \code{wimbledon} è un data frame tbl con 48 osservazioni e 10 variabili.
#' 
#' 
#' @details 
#' Le 10 variabili del data frame tbl \code{wimbledon} sono:
#' \itemize{
#' \item \code{year} Anno del torneo (numerico)
#' \item \code{champion_country} paese di origine del vincitore (character)
#' \item \code{champion} nome e cognome del vincitore (character)
#' \item \code{runner_up_country} paese di origine del secondo classificato (character)
#' \item \code{runner_up} nome e cognome del secondo classificato (character)
#' \item \code{s1,s2,s3,s4,s5} punteggi dei cinque set (character)
#' }
#' 
NULL
##################################################################################################################################

##################################################################################################################################
#' Tornei U.S. Open
#' 
#' 
#' @name usopen
#' 
#' 
#' @description Il dataset \code{usopen} contiene informazioni sulle finali maschili U.S. Open dal 1968 al 2015.
#'  
#' @usage data(usopen)
#' 
#' 
#' @format \code{usopen} è un data frame tbl con 48 osservazioni e 10 variabili.
#' 
#' 
#' @details 
#' Le 10 variabili del data frame tbl \code{usopen} sono:
#' \itemize{
#' \item \code{year} Anno del torneo (numerico)
#' \item \code{champion_country} paese di origine del vincitore (character)
#' \item \code{champion} nome e cognome del vincitore (character)
#' \item \code{runner_up_country} paese di origine del secondo classificato (character)
#' \item \code{runner_up} nome e cognome del secondo classificato (character)
#' \item \code{s1,s2,s3,s4,s5} punteggi dei cinque set (character)
#' }
#' 
NULL
##################################################################################################################################

##################################################################################################################################
#' Matrice di Distanza tra 12 Leader Politici Nazionali Durante la II Guerra Mondiale
#' 
#' 
#' @name wwiileaders
#' 
#' 
#' @description I dati di \code{wwiileaders} contengono una matrice di distanze tra 12 leader politici nazionali durante la II Guerra Mondiale.
#' Le distanze si basano sul giudizio di dissomiglianza ideologica. I soggetti intervistai hanno fornito giudizi su una scala a nove punti,
#' con gli estremi della scala, 1 e 9, che indicano, rispettivamente, "molto simile" e "molto dissimile".
#' 
#'  
#' @usage data(wwiileaders)
#' 
#' 
#' @format \code{wwiileaders} è una matrice di distanze.
#' 
#' 
#' @source Everitt, B. and Hothorn, T., *An Introduction to Applied Multivariate Analysis with `R`*, Springer, 2011
NULL
##################################################################################################################################


##################################################################################################################################
#' Attitudine al Fumo di Diversi Impiegati in una Azienda
#' 
#' 
#' @name smoke
#' 
#' 
#' @description Il dataset \code{smoke} contiene informazioni sull'attitudine al fumo per diversi impiegati di una azienda. 
#' Il data frame è in effetti una tabella di contingenza dell'attitudine al fumo  (None, Light, Medium, Heavy: Nessuna, Leggera, Media, Pesante) Vs. livello impiegatizio  
#' (Senior Manager, Junior Manager, Senior Employee, Junior Employee, Secretary). 
#'  
#' @usage data(smoke)
#' 
#' 
#' @format data frame tbl con 6 osservazioni su 4 variabili con nomi di riga.
#' 
#' 
#' @details 
#' Le 4 variabili sono:
#' \itemize{
#' \item \code{None} Conteggio dei non funatori (numerico)
#' \item \code{Light} Conteggio dei fumatori leggeri (numerico)
#' \item \code{Medium} Conteggio dei fumatori medi (numerico)
#' \item \code{Heavy} Conteggio dei fumatori pesanti (numerico)
#' }
#' 
#' @source Michael J. Greenacre, *Theory and applications of correspondence analysis*, London: Academic Press, 1984

NULL
##################################################################################################################################

##################################################################################################################################
#' Sottopeso alla Nascita 
#' 
#' 
#' @name bwt
#' 
#' 
#' @description I dati sul sottopeso contengono informazione sullo stato di sottopeso per bambini nati in un ospedale degli USA. 
#' Sono state raccolte alcune variabili per cercare di spiegare la causa dell'eventuale sottopeso.
#' 
#'  
#' @usage data(bwt)
#' 
#' 
#' @format \code{bwt} è un data frame tbl con 189 osservazioni su 4 variabili.
#' 
#' 
#' @details 
#' Le 4 variabili del data frame tbl \code{bwt} sono:
#' \itemize{
#' \item \code{low} indicazione del peso alla nascita inferiore a 2.5 kg. (numerico)
#' \item \code{age} età della madre in anni (numerico)
#' \item \code{lwt} peso della madre in pounds all'ultimo ciclo mestruale (numerico)
#' \item \code{smoke} uso di sigarette o fumo durante la gravidanza (factor)
#' }
#' 
#' 
#' @source Hosmer, Jr., D. W. and Lemeshow, S. (1989) _Applied Logistic Regression._ New York: John Wiley and Sons. 
NULL
##################################################################################################################################

##################################################################################################################################
#' Toxoplasmosi
#' 
#' 
#' @name toxo
#' 
#' 
#' @description Questo dataset riporta i valori di prevalenza di toxoplasmosi, un'infezione del sangue endemica, in 34 città di El Salvador.
#' 
#'  
#' @usage data(toxo)
#' 
#' 
#' @format \code{toxo} è un data frame tbl con 34 osservazionsi su 5 variabili.
#' 
#' 
#' @details 
#' Le 5 variabili del data frame tbl \code{toxo} sono:
#' \itemize{
#' \item \code{city} numero della città (numerico)
#' \item \code{rain} pioggia nell'anno (mm) (numerico)
#' \item \code{prop} propozione della popolazione affetta da toxoplasmosi (numerico)
#' \item \code{num} numero di persone analizzate (numerico)
#' \item \code{ill} matrice di due colonne contenente il numero di casi sani (illN) e malati (illY) (matrice numerica)
#' }
#' 
#' 
#' @source Efron, B. (1986). Double Exponential Families and Their Use in Generalized Linear Regression. _Journal of the American Statistical Association_, 81(395), 709-721
NULL
##################################################################################################################################

##################################################################################################################################
#' Misure di Peso e Altezza in un Campione di Giovani
#' 
#' 
#' @name ds
#' 
#' 
#' @description I dati \code{ds} contengono informazioni su peso e altezza di un campione di ragazzi. E' registrato anche il sesso. 
#' 
#' 
#'  
#' @usage data(ds)
#' 
#' 
#' @format \code{ds} è un data frame tbl con 200 osservazioni su 3 variabili.
#' 
#' 
#' @details 
#' Le 3 variabili del data frame tbl \code{ds} sono:
#' \itemize{
#' \item \code{height}  altezza (in cm) (numerico)
#' \item \code{weight}  peso (in Kg) (numerico)
#' \item \code{gender}  sesso (fattore con 2 livelli: \code{M} e \code{F})
#' }
#' 
#' 
#' @source Data set fittizio simulato
NULL
##################################################################################################################################

##################################################################################################################################
#' Temperatura di reazione
#' 
#' 
#' @name reaction
#' 
#' 
#' @description Una teoria in ambito chimico suggerisce che la temperatura a cui si attiva una specifica reazione è di 180 °C. 
#' I dati \code{reaction} contengono i risultati di 10 misurazioni indipendenti di temperatura. 
#' 
#' 
#'  
#' @usage data(reaction)
#' 
#' 
#' @format \code{reaction} è un vettore con 10 osservazioni
#' 
#' 
#' 
NULL
##################################################################################################################################

##################################################################################################################################
#' Ormoni della crescita
#' 
#' 
#' @name hormones
#' 
#' 
#' @description I dati di \code{hormones} contengono i riusltati di un esperimento per confrontare due ormoni della crescita. 
#' Sono stati testati 18 polli: a 10 è stato somminostrato l'ormone A e a 8 è stato somministrato l'ormone B. E' stato misurato l'aumento di peso (grammi) nel peroido di osservazione. 
#' 
#'  
#' @usage data(hormones)
#' 
#' 
#' @format \code{hormones} è un data frame tbl con 18 osservazioni su 2 variabili
#' 
#' 
#' @details 
#' Le 2 variabili del data frame tbl \code{hormones} sono:
#' \itemize{
#' \item \code{hormone} ormone della crescita somministrato al pollo  (fattore con livelli: \code{A} e \code{B})
#' \item \code{gain} aumento di peso (grammi) (numerico)
#' }
#' 
#' 
NULL
##################################################################################################################################

##################################################################################################################################
#' Tempo di Parcheggio
#' 
#' 
#' @name carctl
#' 
#' 
#' @description I dati di \code{carctl} contengono informazioni su un esperimento che analizza se un dispositivo opzionale installato su automobili possa aiutare nel parcheggio delle auto stesse. 
#' E' stato chiesto a 20 giudatori di parcheggiare uno stesso modello di auto, con e senza il dispositivo. 
#' E' stato quindi registrato il tempo di parcheggio (secondi) per ciascun guidatore per entrambe le auto.
#'  
#'  
#' @usage data(carctl)
#' 
#' 
#' @format \code{carctl} è un data frame tbl con 20 osservazioni su 2 variabili.
#' 
#' 
#' @details 
#' Le due variabili del data frame tbl \code{carctl} sono:
#' \itemize{
#' \item \code{Car_A} tempo di parcheggio dell'auto con dispositivo A, cioè senza dispositivo (secondi) (numerico)
#' \item \code{Car_B} tempo di parcheggio dell'auto con dispositivo B, cioè con dispositivo (secondi) (numerico)
#' }
#' 
#' 
NULL
##################################################################################################################################

##################################################################################################################################
#' Tessuti di Sedili per Automobili
#' 
#' 
#' @name tissue
#' 
#' 
#' @description I dati di \code{tissue} contengono misure di resistenza di tessuti di sedili per auto prese da tre ispettori di qualità (operatori) di un impianto produttivo: Henry, Anne, e Andrew (operatori).
#'  Ciascun operatore ha misurato 25 pessi di tesuto. Globalmente, quindi, sono stati campionati e assegnati casualmente 75 pezzi di tessuto prelevati dallo stesso lotto di prodzione.
#'  
#' @usage data(tissue)
#' 
#' 
#' @format \code{tissue} è un data frame tbl con 75 osservazioni su 2 variabili.
#' 
#' 
#' @details 
#' Le 2 variabili del data frame tbl \code{tissue} sono:
#' \itemize{
#' \item \code{Operator} nome dell'ispettore di qualità che misura il tessuto (fattore con livelli: \code{Anne}, \code{Henry} e \code{Andrew})
#' \item \code{Strength} misura di resistenza del tessuto analizzato (numerico)
#' }
#' 
#' 
NULL
##################################################################################################################################

##################################################################################################################################
#' Spazio di Frenata
#' 
#' 
#' @name distance
#' 
#' 
#' @description I dati di \code{distance} contengono misurazioni di spazi di frenata prese su una stessa auto equipaggiata con diverse configurazioni i pneumatico, battisrtada ed ABS.
#'  Per ogni combinazione dei livelli dei tre fattori, sono state effettuate due misurazioni si spazio di frenata.
#'  
#' @usage data(distance)
#' 
#' 
#' @format \code{distance} è un data frame tbl con 24 osservazoni su 4 variabili.
#' 
#' 
#' @details 
#' Le 4 variabili del data frame tbl \code{distance} sono:
#' \itemize{
#' \item \code{Tire} tipo di peumatico (fattore con livelli \code{GT}, \code{LS}, \code{MX})
#' \item \code{Tread} livello di battistrada (fattore con livelli \code{1.5} e \code{10})
#' \item \code{ABS} indica se l'ABS è disattivo (disabled) o attivo (enabled) (fattore con livelli \code{disabled} e \code{enabled})
#' \item \code{Distance} misura dello spazio di frenata (in metri) (numeric)
#' }
#' 
#' 
NULL
##################################################################################################################################

##################################################################################################################################
#' Dati di Anomalie Cromosomiche
#' 
#' 
#' @name dicentric
#' 
#' 
#' @description I dati di \code{dicentric} contengono il numero (\code{ca}) di anomalie cromosomiche osservato per diversi valori di quantità di (\code{doseamt})
#' ed intensità (\code{doserate}) di radiazioni gamma. Il numero di cellule analizzate varia di campione in campione.
#'  
#' @usage data(dicentric)
#' 
#' 
#' @format \code{dicentric} è un data frame tbl con 27 osservazioni su 4 variabii.
#' 
#' 
#' @details 
#' Le 4 variabili del data frame tbl \code{dicentric} sono:
#' \itemize{
#' \item \code{cells} Numero di cellule analizzate (numerico)
#' \item \code{ca} Numero di anomalie cromosomiche trovate (numerico)
#' \item \code{doseamt} Ammontare di radiaazioni gamma (numerico)
#' \item \code{doserate} Intensità della radiazione gamma (numerico)
#' }
#' 
#' 
#' @source Purrott, R. J. and E. Reeder. (1976) "The effect of changes in dose rate on the yield of chromosome aberrations in human lymphocytes exposed to gamma radiation." _Mutat. Res_ (35), 437–444
NULL
##################################################################################################################################

##################################################################################################################################
#' Diametri Tondini
#' 
#' 
#' @name diameters
#' 
#' 
#' @description I dati di \code{diameters} contengono misurazioni prese da cinque torni diversi; ogni tornio è usato da due operatori diversi.
#'  
#' @usage data(diameters)
#' 
#' 
#' @format \code{diameters} è un data frame tbl con 50 osservazioni su 3 variabili.
#' 
#' 
#' @details 
#' Le 3 variabili del data frame tbl \code{diameters} sono:
#' \itemize{
#' \item \code{Lathe} tornio (fattore con livelli \code{1}, \code{2}, \code{3}, \code{4}, \code{5})
#' \item \code{Operator} operatore (fattore con livelli \code{D} e \code{N})
#' \item \code{Pin.Diam} misura del diametro del tondino (numerico)
#' }
#' 
#' 
NULL
##################################################################################################################################

##################################################################################################################################
#' I Dati di Raftery e Hout sul Livello Scolastico Irlandese
#' 
#' 
#' @name irished
#' 
#' 
#' @description I dati \code{irished} contengono informazioni sulle transizioni scolastiche per un campione di 500 scolari irlandesi di 11 anni nel 1967.
#'  
#' @usage data(irished)
#' 
#' 
#' @format \code{irished} è un data frame tbl con 500 osservazioni su 6 variabili.
#' 
#' 
#' @details 
#' Le 6 variabili del data frame tbl \code{irished} sono:
#' \itemize{
#' \item \code{Sex} Fattore con livelli 1 = maschio; 2 = femmina
#' \item \code{DVRT} Punteggio del Drumcondra Verbal Reasoning Test (numerico)
#' \item \code{edlevel} Livello scolastico raggiunto:
#'\enumerate{
#'\item Primary terminal leaver
#'\item Junior cycle incomplete: vocational school
#'\item Junior cycle incomplete: secondary school
#'\item Junior cycle terminal leaver: vocational school
#'\item Junior cycle terminal leaver: secondary school
#'\item Senior cycle incomplete: vocational school
#'\item Senior cycle incomplete: secondary school
#'\item Senior cycle terminal leaver: vocational school
#'\item Senior cycle terminal leaver: secondary school
#'\item 3rd level incomplete
#'\item 3rd level complete
#'  }
#' \item \code{lvcert} Certificato. Fattore con 2 livelli: 1 se non è stato ottenuto il certificato; 2 se ottenuto.
#' \item \code{fathocc} Punteggio di prestigio per l'occupazione del padre (calcolato da Raftery e Hout, 1985) (numerico)
#' \item \code{schltype} Tipo di scuola. Fattore con3 livelli: 1 = secondary; 2 = vocational; 9 = primary terminal leaver.
#' }
#' 
#' 
#' @source Dati raccolti da Greaney and Kelleghan (1984), e rianalizzati da Raftery and Hout (1985, 1993)
NULL
##################################################################################################################################

##################################################################################################################################
#' Dataset Bollitura
#' 
#' 
#' @name boiling
#' 
#' 
#' @description I seguenti dati sono stati ottenuti nel tentativo di risolvere una disputa domestica su quale di due padelle avesse il tempo di cottura più breve.
#' Diverse misure di volume (pinte) di acqua fredda sono state messe in ciascuna delle padelle usando le stesse impostazioni per i fornelli.
#' La variabile di risposta è stato il tempo in minuti (`time`) per far bollire l'acqua.
#' 
#'  
#' @usage data(boiling)
#' 
#' 
#' @format \code{boiling} è un data frame tbl con 6 osservazioni su 3 variabili.
#' 
#' 
#' @details 
#' Le 3 variabili del \code{boiling} data frame tbl sono le seguenti:
#' \itemize{
#' \item \code{time} temppo alla bollitura (minuti) (numerico);
#' \item \code{pan} tipo di pdella (fattore).
#' \item \code{volume} volume dell'aaqua (pinte) (numerico).
#' }
#' 
#' 
NULL
##################################################################################################################################

##################################################################################################################################
#' Temp di Reazione
#' 
#' 
#' @name drug
#' 
#' 
#' @description I dataset \code{drug} contiene i risultati di un esperimento per indagare l'effetto si un farmaco tranquillante. In particolare,
#'  sono stati misurati i tempi di reazione ad un determinato stimolo di 10 ratti maschi dopo che è stata somministrata loro una dose specifica del formaco.
#' 
#'  
#' @usage data(drug)
#' 
#' 
#' @format \code{drug} è un data frame tbl con 10 osservazioni su 3 variabili.
#' 
#' 
#' @details 
#' Le 3 variabili del data frame tbl \code{drug} sono:
#' \itemize{
#' \item \code{rat} identificativo del ratto (numerico);
#' \item \code{dose} dose specificata di farmaco sommistrato (numerico);
#' \item \code{time} tempo di reazione (numerico).
#' }
#' 
#' 
NULL
##################################################################################################################################


##################################################################################################################################
#' Strumenti per la Misurazion del pH
#' 
#' 
#' @name labonline
#' 
#' 
#' @description  Sono confrontati due strumenti di misura del pH: uno strumento è un "gold standard", ed è di "laboratorio", l'altro è uno strumento on-line (sul campo).
#'  Sono stati misurati alcuni campioncini di materiale usando entrambi gli strumenti per vedere se lo strumento on-line ottiene risultati simili a quelli dello strumento di laboratorio.
#' 
#' @usage data(labonline)
#' 
#' 
#' @format \code{labonline} è un data frame tbl con 20 osservazioni su 2 variabili.
#' 
#' 
#' @details 
#' Le 2 variabili del data frame tbl \code{labonline} sono:
#' \itemize{
#' \item \code{Lab} misurazioni raccolte con lo strumento di "laboratorio" (numerico)
#' \item \code{Online} misurazioni raccolte con lo strumento on-line (numerico)
#' }
#' 
#' 
NULL
##################################################################################################################################

##################################################################################################################################
#' Studio sulla Poliesterificazione
#' 
#' 
#' @name polyester
#' 
#' 
#' @description  Nello studio sulla poliesterificazione di acidi grasi con glicoli, è stato investicato l'effetto della temperatura (C)
#' sulla percentuale di conversione del processo di esterificazione. 
#' I dati sono il risultato di un esperimento che usa un catalizzatore 0.0004 mole zinc chloride per 100 grammi di acidi grassi.
#' 
#' @usage data(polyester)
#' 
#' 
#' @format \code{polyester} è un data frame tbl con 6 osservaizoni su 2 variabili
#' 
#' 
#' @details 
#' Le 2 variabili del data frame tbl \code{polyester} sono:
#' \itemize{
#' \item \code{temperature} temperatura (numerico)
#' \item \code{conversion} percentuale di conversione del processo di esterificazione (numerico)
#' }
#' 
#' 
NULL
##################################################################################################################################

##################################################################################################################################
#' Dataset Coagulazione
#' 
#' 
#' @name clotting
#'  
#' @description Da McCullagh and Nelder (1989, pp. 300-302). Hurn et al. (1945) i dati pubblicati sul tempo di coagulazione del sangue, 
#' che ritornano i tempi di coagulazione in secondi (y) per plasma normale diluto su nove diverse percentuali di concentrazione con plasma senza protrombina
#' (u); la coagulazione è stata indotta tramite due lotti di tromboplastine. I dati sono analizzati usando errori distribuiti come una gamma link inversa.
#' 
#'  
#' @usage data(clotting)
#' 
#' 
#' @format \code{clotting} è un data frame tbl con 18 osservazioni su 3 variabili.
#' 
#' 
#' @details 
#' Le 3 variabili del data frame tbl \code{clotting} sono:
#' \itemize{
#' \item \code{u} percentuale di diluizione (numerico).
#' \item \code{y} temppo di coagulazione (sec) (numerico);
#' \item \code{lot} lotto di tromboplastina (fattore).
#' }
#' 
#' 
#' @source Hurn, M.W., Baker, N.W. and Magath, T.D. (1945) "The determination of prothrombin time following the administration of dicumarol with specific reference to thromboplastin". _J. Lab. Clin. Med._ __30__, 432-47
NULL
##################################################################################################################################

##################################################################################################################################
#' Dataset nes96
#' 
#' 
#' @name nes96
#'   
#' @description Sottoinsieme di 10 variabili del American National Election Study del 1996. I casi con valori mancanti o risposte "non so" sono stati eliminati completamente. Gli intervistati che hano espresso una preferenza di voto diversa da Clinton o Dole sono stati rimossi.
#'
#'
#' @usage data(nes96)
#'  
#' @format \code{nes96} è un data frame tbl con 944 osservazioni su 10 variabili.
#'  
#' @details 
#' Le 10 variabili del data frame tbl \code{nes96} sono:
#' \itemize{
#' \item \code{popul} popolazione della località dell'intervistato migliaia di persone (numerico).
#' \item \code{TVnews} giorni in cui l'intervistato ha dedicato tempo nell'ultima settimana per gardare le notizie in TV (numerico);
#' \item \code{selfLR} Posizionamento politico da sinistra a destra espresso dagli intervistati: un fattore ordinato con livelli extremely liberal, extLib < liberal, Lib < slightly liberal, sliLib < moderate, Mod < slightly conservative, sliCon < conservative, Con < extremely conservative, extCon.
#' \item \code{ClinLR} Posizionamento politico da sinistra a destra di Bill Clinton (stessa scala di selfLR): fattore ordinato con livelli extLib < Lib < sliLib < Mod < sliCon < Con < extCon (factor).
#' \item \code{DoleLR} Posizionamento politico da sinistra a destra di Bob Dole (stessa scala di selfLR): fattore ordinato con livelli extLib < Lib < sliLib < Mod < sliCon < Con < extCon (factor).
#' \item \code{PID} Identificazione del partito: un fattore ordinato con livelli strong Democrat, strDem < weak Democrat, weakDem < independent Democrat, indDem < independent independentindind < indepedent Republican, indRep < waek Republican, weakRep < strong Republican, strRep.
#' \item \code{age} Età dell'intervistato in anni (numerico).
#' \item \code{educ} Livello di studio dell'intevistato: un fattore ordinato con livelli 8 years or less, MS < high school dropout, HSdrop < high school diploma or GED, HS < some College, Coll < Community or junior College degree, CCdeg < BA degree, BAdeg < postgraduate degree, MAdeg.
#' \item \code{income} Reddito familiare dell'intervistato: un fattore ordinato con livelli $3Kminus < $3K-$5K < $5K-$7K < $7K-$9K < $9K-$10K < $10K-$11K < $11K-$12K < $12K-$13K < $13K-$14K < $14K-$15K < $15K-$17K < $17K-$20K < $20K-$22K < $22K-$25K < $25K-$30K < $30K-$35K < $35K-$40K < $40K-$45K < $45K-$50K < $50K-$60K < $60K-$75K < $75K-$90K < $90K-$105K < $105Kplus.
#' \item \code{vote} Voto atteso nelle elezioni presidenziali del  1996: un fattore con livelli Clinton e Dole.
#' }
#' 
#' 
#' @source Sapiro, Virginia, Steven J. Rosenstone, Donald R. Kinder, Warren E. Miller, and the National Election Studies. AMERICAN NATIONAL ELECTION STUDIES, 1992-1997: COMBINED FILE [Computer file]. 2nd ICPSR version. Ann Arbor, MI: University of Michigan, Center for Political Studies [producer], 1999. Ann Arbor, MI: Inter-university Consortium for Political and Social Research [distributor], 1999
NULL
##################################################################################################################################

##################################################################################################################################
#' Janka Hardness
#' 
#' 
#' @name janka
#' 
#' 
#' @description  Janka Hardness è un importante indice di valutazione della durezza di legname Australiano. 
#' Il test misura la forza richiesta per spingere una pallina di acciaio all'interno di un pezzo di legno e
#' pertanto fornisce una buona indicazione di come il legno resisteà alle ammaccature e all'usura. 
#' Il dataset consiste di misurazioni di densità e durezza per 36 blocchi di legno massiccio di Eucalipto australiano.
#' 
#' @usage data(janka)
#' 
#' 
#' @format \code{janka} è un data frame  tbl con 36 osservazioni su 2 variabili.
#' 
#' 
#' @details 
#' Le 2 variabili del data frame tbl \code{janka} sono:
#' \itemize{
#' \item \code{Density} misure di densità (numerico)
#' \item \code{Hardness} janka hardness (numerico)
#' }
#' 
#' 
NULL
##################################################################################################################################

##################################################################################################################################
#' Inquinamento dell'Aria
#' 
#' 
#' @name oxidant
#' 
#' 
#' @description Il dataset \code{oxidant} contiene dati sul livello di un inuinante dell'aria, "Oxidant", 
#' insieme ai livelli di quattro variabili meteorologiche registrate in 30 giorni di una estate.  
#' 
#' @usage data(oxidant)
#' 
#' 
#' @format \code{oxidant} è un data frame tbl con 30 osservazioni su 6 variabili.
#' 
#' 
#' @details 
#' Le 6 variabili del data frame tbl \code{oxidant} sono:
#' \itemize{
#' \item \code{day} indice del giorno (numerico)
#' \item \code{windspeed} misura della velocità del vento (numerico)
#' \item \code{temperature} misura della temperatura (numerico)
#' \item \code{humidity} misura dell'umidità (numerico)
#' \item \code{insolation} misura del livello di irmeasure of insolazione (numerico)
#' \item \code{oxidant} misura di ossidante (numerico)
#' }
#' 
#' 
NULL
##################################################################################################################################

##################################################################################################################################
#' Hot Dog 
#' 
#' 
#' @name hotdogs
#' 
#' 
#' @description I dati \code{hotdogs} contengono i valori di calorie e contenuto di sodio per tre tipi di hot dog: 
#' 20 Bovini, 17 Carne e 17 Pollame. Questi dati sono un campione da una popolazione più ampia.
#' 
#' @usage data(hotdogs)
#' 
#' 
#' @format \code{hotdogs} è un data frame tbl con 54 osservazioni su 3 variabili.
#' 
#' 
#' @details 
#' Le 3 variabili del data frame tbl \code{hotdogs} sono:
#' \itemize{
#' \item \code{type} tipo di hot dog (fattore con livelli: \code{beef}, \code{meat} e \code{poultry})
#' \item \code{calories} contenuto in Kcal (numerico)
#' \item \code{sodium} contenuto in sodio (numerico)
#' }
#' 
#' 
NULL
##################################################################################################################################

##################################################################################################################################
#' Caratteristiche della Popolazione
#' 
#' 
#' @name istat
#' 
#' 
#' @description I dati \code{istat} contengono peso, altezza, sesso e area geografica 
#' ("Nord", "Centro", "Sud" e "Isole") per 1806 persone italiane.
#' 
#'  
#' @usage data(istat)
#' 
#' 
#' @format \code{istat} è un data frame tbl con 1806 osservazioni su 4 variabili.
#' 
#' 
#' @details 
#' Le 4 variabili del data frame tbl \code{istat} sono:
#' \itemize{
#' \item \code{Gender} sesso (fattore con livelli: \code{Female} e \code{Male})
#' \item \code{Area} area geografica (fattore con livelli: \code{Nord}, \code{Centro}, \code{Sud} e \code{Isole})
#' \item \code{Weight} peso in kg (numerico)
#' \item \code{Height} altezza in cm (numerico)
#' }
#' 
#' 
#' @source dati ISTAT
NULL
##################################################################################################################################

##################################################################################################################################
#' Produzione di Grano
#' 
#' 
#' @name iowheat
#' 
#' 
#' @description Il dataset \code{iowheat} è un esempio "giocattolo" che riassume la produzione del grano (staia per acro) 
#' per lo stato dell'Iowa tra il 1930 e il 1962. Oltre alla produzione, sono registrati anche l'anno, le piogge e la temperatura 
#' come predittori principali del raccolto.
#' 
#'  
#' @usage data(iowheat)
#' 
#' 
#' @format \code{iowheat} è un data frame tbl con 33 osservazioni su 10 variabili.
#' 
#' 
#' @details 
#' Le 10 variabili del data frame tbl \code{iowheat} sono:
#' \itemize{
#' \item \code{Year} anno del raccolto (numerico)
#' \item \code{Rain0} piogge precedenti la stagione (numerico)
#' \item \code{Temp1} temperatura media per il mese di crecita 1 (numerico)
#' \item \code{Rain1} pioggia per il mese di crescita 1 (numerico)
#' \item \code{Temp2} temperatura media per il mese di crecita 2 (numerico)
#' \item \code{Rain2} pioggia per il mese di crescita 2 (numerico)
#' \item \code{Temp3} temperatura media per il mese di crecita 3 (numerico)
#' \item \code{Rain3} pioggia per il mese di crescita 3 (numerico)
#' \item \code{Temp4} temperatura media per il mese del raccolto (numerico)
#' \item \code{Yield} raccolto in stai per acro (numerico)
#' }
#' 
#' 
NULL
##################################################################################################################################

##################################################################################################################################
#' Diametro Medio di Tappi Prodotti da una Macchina a Stampo
#' 
#' 
#' @name bottlecap
#' 
#' 
#' @description Il dataset \code{bottlecap} contiene misure di diametro medio dei tappi prodotti da una macchina a stampo
#' 
#'  
#' @usage data(bottlecap)
#' 
#' 
#' @format \code{bottlecap} è un data frame tbl con 840 osservazioni su 8 variabili.
#' 
#' 
#' @details 
#' Le 8 variabili del data frame tbl \code{bottlecap} sono:
#' \itemize{
#' \item \code{Cavity.1} misure di diametro medio dei tappi prodotti dalla cavità 1 (numerico)
#' \item \code{Cavity.2} misure di diametro medio dei tappi prodotti dalla cavità 2 (numerico)
#' \item \code{Cavity.3} misure di diametro medio dei tappi prodotti dalla cavità 3 (numerico)
#' \item \code{Cavity.4} misure di diametro medio dei tappi prodotti dalla cavità 4 (numerico)
#' \item \code{Cavity.5} misure di diametro medio dei tappi prodotti dalla cavità 5 (numerico)
#' \item \code{Cavity.6} misure di diametro medio dei tappi prodotti dalla cavità 6 (numerico)
#' \item \code{Cavity.7} misure di diametro medio dei tappi prodotti dalla cavità 7 (numerico)
#' \item \code{Cavity.8} misure di diametro medio dei tappi prodotti dalla cavità 8 (numerico)
#' }
#' 
#' 
NULL
##################################################################################################################################

##################################################################################################################################
#' Riempimento di Scatole di Cereali
#' 
#' 
#' @name cerealbx
#' 
#' 
#' @description Il dataset \code{cerealbx} contiene dati di riempimento di scatole di cereali.
#' 
#'  
#' @usage data(cerealbx)
#' 
#' 
#' @format \code{cerealbx} è un data frame tbl con 6 osservazioni su 1 variabile.
#' 
#' 
#' @details 
#' La variabile del data frame tbl \code{cerealbx} è:
#' \itemize{
#' \item \code{BoxWeigh} peso del contenuto della scatola di cereali (g) (numerico)
#' }
#' 
#' 
NULL
##################################################################################################################################

##################################################################################################################################
#' Confronto di due Fornitori di Materiali Plastici
#' 
#' 
#' @name plastic
#' 
#' 
#' @description \code{plastic} contiene dati di misurazioni di resistenza di wafer di plastica di due fornitori diversi.
#' 
#'  
#' @usage data(plastic)
#' 
#' 
#' @format \code{plastic} è un data frame tbl con 20 osservazioni su 2 variabili.
#' 
#' 
#' @details 
#' Le 2 variabili del data frame tbl \code{plastic} sono:
#' \itemize{
#' \item \code{SupplrA} resistenza dei wafer di plastica forniti dal fornitore A (N) (numerico)
#' \item \code{SupplrB} resistenza dei wafer di plastica forniti dal fornitore B (N) (numerico)
#' }
#' 
#' 
NULL
##################################################################################################################################

##################################################################################################################################
#' Resistenza allo Strappo
#' 
#' 
#' @name sturdy
#' 
#' 
#' @description I dati \code{sturdy} contengono misurazoni si resistenza allo strappo di cinque diversi marchi di impermeabili.
#' 
#'  
#' @usage data(sturdy)
#' 
#' 
#' @format \code{sturdy} è un data frame tbl con 26 osservazioni su 2 variabili.
#' 
#' 
#' @details 
#' Le 2 variabili del data frame tbl \code{sturdy} sono:
#' \itemize{
#' \item \code{Time} tempo trascorso tra la sollecitazione e lo strappo (minuti) (numerico)
#' \item \code{Groups} marchio dell'impermeabile  (fattore con livelli: \code{A}, \code{B}, \code{C} e \code{D})
#' }
#' 
#' 
NULL
##################################################################################################################################


##################################################################################################################################
#' Effect of toxic agent
#' 
#' 
#' @name rats
#' 
#' 
#' @description \code{rats} contiene misurazioni sulla sopravvivenza di un campione di ratti
#'  a cui sono stati somministrati tre tipi di veleno e quattro tipi di trattamento. Ogni
#'  combinazione veleno-trattamento è stata somministrata a 4 ratti.
#' 
#'  
#' @usage data(rats)
#' 
#' 
#' @format \code{rats} è un data frame tbl con 48 osservazioni su 3 variabili.
#' 
#' 
#' @details 
#' Le 3 variabili del data frame tbl \code{rats} sono:
#' \itemize{
#' \item \code{Time} tempo di sopravvivenza (ore) (numerico)
#' \item \code{Poison} tipo di veleno (fattore con livelli: \code{I}, \code{II} e \code{III})
#' \item \code{Treatment} tipo di trattamento (fattore con livelli: \code{A}, \code{B}, \code{C} e \code{D})
#' }
#' 
#' 
NULL
##################################################################################################################################

##################################################################################################################################
#' Analisi dei Dati sui Passeggeri del Titanic
#' 
#' 
#' @name titanic
#' 
#' 
#' @description \code{titanic} contiene dati personali e di viaggio dei singoli passeggeri, 
#' nonché se il passeggero è spravissuto o meno.
#' 
#'  
#' @usage data(titanic)
#' 
#' 
#' @format \code{titanic} è un data frame tbl con 2201 osservazioni su 4 variabili.
#' 
#' 
#' @details 
#' Le 4 variabili del data frame tbl \code{titanic} sono:
#' \itemize{
#' \item \code{Class} classe di viaggio (fattore con due livelli: \code{First} e \code{Coach})
#' \item \code{Gender} sesso del passeggero (fattore con due livelli: \code{Male} e \code{Female})
#' \item \code{Age} età del passeggero (numerico)
#' \item \code{Status} stato del passeggero (fattore con due livelli: \code{Died} e \code{Survived})
#' }
#' 
#' 
NULL
##################################################################################################################################

##################################################################################################################################
#' Cancro della Pelle
#' 
#' 
#' @name skin
#' 
#' 
#' @description 400 sono stati classificati rispetto al tipo di cancro e al sito in cui il tumore è stato individuato.
#' 
#'  
#' @usage data(skin)
#' 
#' 
#' @format \code{skin} è un data frame tbl con 12 osservazioni su 3 variabili.
#' 
#' 
#' @details 
#' Le 3 variabili del data frame tbl \code{skin} sono:
#' \itemize{
#' \item \code{Counts} conteggio dei pazienti (numerico)
#' \item \code{Type} tipo di cancro (fattore con quattro livelli: \code{Melan}, \code{Super}, \code{Nodul} e \code{Indet})
#' \item \code{Site} localizzazione del tumore (fattore con tre livelli: \code{Extr}, \code{HeadN} e \code{Trunk})
#' }
#' 
#' 
NULL
##################################################################################################################################

##################################################################################################################################
#' Ozono 
#' 
#' 
#' @name ozone
#' 
#' 
#' @description \code{ozone} contaiene dati di misurazione dell'ozono da Breiman and Friedman, 1985 
#' 
#'  
#' @usage data(ozone)
#' 
#' 
#' @format \code{ozone} è un data frame tbl con 330 osservazioni su 9 variabili.
#' 
#' 
#' @details 
#' Le 9 variabili del data frame tbl \code{ozone} sono:
#' \itemize{
#' \item \code{O3} concentrazinoe di ozono, ppm, a Sandbug AFB. (numerico)
#' \item \code{temp} Temperatura gradi F. (max). (numerico)
#' \item \code{ibh} Altezza della base di inversione, piedi (numerico)
#' \item \code{Pres} Gradiente di pressione di Daggett (mm Hg) (numerico)
#' \item \code{Vis} Visibilità (miglia) (numerico)
#' \item \code{Hgt} Altezza 500 millibar di Vandenburg (m) (numerico)
#' \item \code{Hum} Umidità percentuale (numerico)
#' \item \code{ibt} Temperatura della base di inversione, gradi F. (numerico)
#' \item \code{Wind} Velocità del vento, mph (numerico)
#' }
#' 
#' 
NULL
##################################################################################################################################
 
##################################################################################################################################
#' Tabella di Frequenze da una Indagine sulle Condizioni di Affitto a Copenhagen 
#' 
#' 
#' @name housing
#' 
#' 
#' @description \code{housing} contiene informazioni sulle condizioni degli affitti a Copenhagen per 1681 affittuari intervistati su: 
#' il tipo di sistemazione di affitto, il livello di contatto che hanno con gli altri residenti, la loro percezione di influenza sulla gestione dell'appatamento,
#' e il loro livello di soddisfazione rispetto alle loo condizioni in affitto.
#' 
#'  
#' @usage data(housing)
#' 
#' 
#' @format \code{housing} è un data frame tbl con 72 osservazioni su 5 variabili.
#' 
#' 
#' @details 
#' Le 5 variabili del data frame tbl \code{housing} sono:
#' \itemize{
#' \item \code{Sat} Soddisfazione degli inquilini rispetto alle loro condizioni attuali (fattore con livelli: \code{High}, \code{Medium} e \code{Low})
#' \item \code{Infl} Grado di influenza percepito dagli inquilini sui gestori della proprietà (fattore con linvelli: \code{High}, \code{Medium} e \code{Low})
#' \item \code{Type} Tipo di sistemazione in affitto (fattore con livelli: \code{Tower}, \code{Atrium}, \code{Apartment} e \code{Terrace})
#' \item \code{Cont} contatto dei residenti con altri residenti (fattore con livelli: \code{(Low} e \code{High})
#' \item \code{Freq} Frequenze: il numero di residenti in ciascuna classe (numerico)
#' }
#' 
#' 
#' @source La pagina di help completa su \code{housing} si può trovare nel package \code{MASS}: \code{\link[MASS]{housing}}
NULL
##################################################################################################################################

##################################################################################################################################
#' Assenteismo Scolastico nelle Zone Rurali del Nuovo Galles del Sud
#' 
#' 
#' @name quine
#' 
#' 
#' @description \code{quine} contiene informazioni su bambini di Walgett, Nuovo Galles del Sud, 
#' Australia, classificati in base alla capacità di apprendimento, età, sesso, livello scolastico, ed il numero di assenze  
#' da scuola in un particolare anno scolastico.
#' 
#'  
#' @usage data(quine)
#' 
#' 
#' @format \code{quine} è un data frame tbl con 146 osservazioni su 5 variabili.
#' 
#' 
#' @details 
#' Le 5 variabili del data frame tbl \code{quine} sono:
#' \itemize{
#' \item \code{Eth} provenienza etnica: Aborigino o Non aborigeno (fattore con livelli: \code{A} e \code{N})
#' \item \code{Sex} sesso (fattore con livelli: \code{F} e \code{M})
#' \item \code{Age} gruppo d'età (fattore con livelli: \code{F0}, \code{F1}, \code{F2} e \code{F3})
#' \item \code{Lrn} capacità di apprendimento (fattore con livelli: \code{(AL} (apprendimento medio) e \code{SL} (apprendimento lento))
#' \item \code{Days} giornate di assenza da scuole nell'anno
#' }
#' 
#' 
#' @source La pagina di help completa su \code{quine} si può trovare nel package \code{MASS}: \code{\link[MASS]{quine}}
NULL
##################################################################################################################################

##################################################################################################################################
#' Impurità nelle Vernici
#' 
#' 
#' @name paint
#' 
#' 
#' @description \code{paint} contiene i risultati di un esperimento finalizzato a determinare la relazione tra il tasso di 
#' agitazione applicato al contenitore della vernice ed il numero di grumi presenti nei contenitori.
#' 
#'  
#' @usage data(paint)
#' 
#' 
#' @format \code{paint} è un data frame tbl con 12 osservazioni su 2 variabili.
#' 
#' 
#' @details 
#' Le 2 variabili del data frame tbl \code{paint} sono:
#' \itemize{
#' \item \code{Stirrate} tasso d'agitazione (rivoluzione) applicato al contenitore (rpm, giri al minuto) (numerico)
#' \item \code{Impurity} numero di impurità (grumi) presenti nel contenitore di vernice (numerico)
#' }
#' 
#' 
NULL
##################################################################################################################################

##################################################################################################################################
#' Pressione Interruttore
#' 
#' 
#' @name switchp
#' 
#' 
#' @description \code{switchp} contiene misure di pressione (KPa) applicate per far scattare 25 interruttori la cui pressione di apertura è determinata dallo spessore di una membrana (diaframma) contenuta.
#' 
#'  
#' @usage data(switchp)
#' 
#' 
#' @format \code{switchp} è un data frame tbl con 25 osservazioni su 2 variabili.
#' 
#' 
#' @details 
#' Le 2 variabili del data frame tbl \code{switchp} sono:
#' \itemize{
#' \item \code{DThickness} lo spesso del diaframma dell'interruttore (mm) (numerico)
#' \item \code{SetPoint} la pressione a cui l'interruttore è scattato (KPa) (numerico)
#' }
#' 
#' 
NULL
##################################################################################################################################

##################################################################################################################################
#' Battito in Testa di Motore
#' 
#' 
#' @name knock
#' 
#' 
#' @description Gli ingegneri vogliore ridurre il livello di "battito in testa" di un modello di motore a scoppio. Per fare ciò, 
#' essi devono identificare quali variabili incluse nel dataset \code{knock} impattano sul fenomeno. 
#' I dati sono stati raccolti da 13 motori scelti casualmente
#' 
#'  
#' @usage data(knock)
#' 
#' 
#' @format \code{knock} è un data frame tbl con 13 osservazioni su 5 variabili.
#' 
#' 
#' @details 
#' Le 5 variabili del data frame tbl \code{knock} sono:
#' \itemize{
#' \item \code{Spark} tempo di antcipo della scintilla della candela (numerico)
#' \item \code{AFR} (Air Fuel Ratio) rappporto aria su carburante (numerico)
#' \item \code{Intake} temperatura all'ingresso (numerico)
#' \item \code{Exhaust} temperatura esausto (numerico)
#' \item \code{Knock} battito in testa del motore (numerico)
#' }
#' 
#' 
NULL
##################################################################################################################################

##################################################################################################################################
#' Mortalità nelle Città Americane più Importanti
#' 
#' 
#' @name mortality
#' 
#' 
#' @description Il dataset \code{mortality} contiene informazioni sulla percentuale di mortalitò per diverse città americane.
#' 
#'  
#' @usage data(mortality)
#' 
#' 
#' @format \code{mortality} è un data frame tbl con 60 osservazioni su 15 variabili.
#' 
#' 
#' @details 
#' Le 15 variabili del data frame tbl \code{mortality} sono:
#' \itemize{
#' \item \code{Rain} piovosità media annuale (numerico)
#' \item \code{JanTemp} temperature medie a gennaio (numerico)
#' \item \code{JulyTemp} temperature medie a Luglio (numerico)
#' \item \code{PctOver65} percntuale di popolazione con più di 65 anni (numerico)
#' \item \code{HHSize} dimensione media delle case (numerico)
#' \item \code{Education} anni di studi scolastici (numerico)
#' \item \code{PctHomesLiveable} percentuale di case “abitabili” (numerico)
#' \item \code{PopDensity} densitò di popolazione (numerico)
#' \item \code{PctLowIncome} percentuale di famiglie con basso reddito (numerico)
#' \item \code{PctWhiteCollar} percentuale di impiegati (numerico)
#' \item \code{Hydrocarbon} livello di inquinamento da idrocarburi (numerico)
#' \item \code{NititeOxide} livello di inquinamento da ossido d'azoto (numerico)
#' \item \code{SulphurDioxide} livello di inquinamento da biossido di zolfo (numerico)
#' \item \code{RelHum} umidità relativa media annua alle 1PM (numerico)
#' \item \code{MortalityRate} tasso di mortalità su 100000 persone (numerico)
#' }
#' 
#' 
#' @source I dati sono stati adattati dal sito web StatLib. 
NULL
##################################################################################################################################

##################################################################################################################################
#' Peso del Corso e del Cervello
#' 
#' 
#' @name brainbod
#' 
#' 
#' @description Il dataset \code{brainbod} contiene informazioni sul peso del corpo e del cervello di diverse specie di animali.
#' 
#'  
#' @usage data(brainbod)
#' 
#' 
#' @format \code{brainbod} è un data frame tbl con 15 osservazioni su 3 variabili.
#' 
#' 
#' @details 
#' Le 3 variabili del data frame tbl \code{brainbod} sono:
#' \itemize{
#' \item \code{Species} specie animale (character)
#' \item \code{Body} peso dell'animale (in kg) (numerico)
#' \item \code{Brain} peso del cervello dell'animale (in g) (numerico)
#' }
#' 
#' 
NULL
##################################################################################################################################

##################################################################################################################################
#' Students awards number
#' 
#' 
#' @name awards
#' 
#' 
#' @description Il dataset \code{awards} contiene informazioni sul numero di premi ottenuti da studenti di una scuola superiore, 
#' il tipo di programma in cui lo studente si è iscritto  (per es., professionale, generale o accademico) e il punteggio del suo esame finale in matematica.
#' 
#'  
#' @usage data(awards)
#' 
#' 
#' @format \code{awards} è un data frame tbl con 200 osservazioni su 4 variabili.
#' 
#' 
#' @details 
#' Le 4 variabili del data frame tbl \code{awards} sono:
#' \itemize{
#' \item \code{id} identificativo dello studente (numerico)
#' \item \code{num_awrds} numero di premi ottenuti dallo studente nelle scuola superiore in un anno (numeric)
#' \item \code{prog} tipo di programma in cui lo studente è stato iscritto (fattore con livelli: \code{(1} (General), \code{(2} (Academic) e \code{3} (Vocational))
#' \item \code{math} punteggio dello studente nell'esame finale di matematica (numerico)
#' }
#' 
#' 
#' @source \url{http://www.ats.ucla.edu/stat/r/dae/poissonreg.htm}
NULL
##################################################################################################################################

##################################################################################################################################
#' Ammissione alla Scuola di Specializzazione
#' 
#' 
#' @name admission
#' 
#' 
#' @description Il dataset \code{admission} contiene informazioni su come GRE (Graduate Record Exam scores), 
#' GPA (grade point average) ed il prestigio dell'istituto universitario, influenzino l'ammissione a scuole di specializzazione.
#'  
#' @usage data(admission)
#' 
#' 
#' @format \code{admission} è un data frame tbl con 400 osservazioni su 4 variabili.
#' 
#' 
#' @details 
#' Le 4 variabili del data frame tbl \code{admission} sono:
#' \itemize{
#' \item \code{admit} ammissione alla scuola di specializzazione (variabile binaria: \code{0} (Non ammesso) e \code{1} (Ammesso))
#' \item \code{gre} GRE (Graduate Record Exam scores) (numerico)
#' \item \code{gpa} GPA (grade point average)  (numerico)
#' \item \code{rank} prestigio dell'istituto universitario (fattore con livelli: \code{(1} (prestigio più elevato), \code{(2}, \code{3} and \code{4} (prestigio più basso))
#' }
#' 
#' 
#' @source \url{http://www.ats.ucla.edu/stat/r/dae/logit.htm}
NULL
##################################################################################################################################

##################################################################################################################################
#' Macchina Multitestina
#' 
#' 
#' @name pencap
#' 
#' 
#' @description Il dataset \code{pencap} contiene informazioni sulla larghezza di tappi di penne prodotte da 16 differenti testine.
#'  
#' @usage data(pencap)
#' 
#' 
#' @format \code{pencap} è un data frame tbl con 320 osservazioni su 2 variabili.
#' 
#' 
#' @details 
#' Le 2 variabili del data frame tbl \code{pencap} sono:
#' \itemize{
#' \item \code{Cavity} numero di testina (numerico)
#' \item \code{Width} misurazione (in mm) (numerico)
#' }
#' 
#' 
NULL
##################################################################################################################################

##################################################################################################################################
#' Solvente per Smalti
#' 
#' 
#' @name varnish
#' 
#' 
#' @description Il dataset \code{varnish} contiene informazioni su un esperimento per valutare l'efficacia di un solvente per sciogliere macchie
#' di smalto per unghie da tessuti. L'esperimento consiste nell'immersione di 5 tessuti macchiati con un certo tipo di smalo in una vaso con un
#' solvente, e misurare il tempo (in minuti) necessario per to dissolvere la macchia.
#'  
#' @usage data(varnish)
#' 
#' 
#' @format \code{varnish} è un data frame tbl con 30 osservazioni su 3 variabili.
#' 
#' 
#' @details 
#' Le 3 variabili del data frame tbl \code{varnish} sono:
#' \itemize{
#' \item \code{Solvent} tipo di solvente (numerico con due valori: \code{1} e \code{2})
#' \item \code{Varnish} tipo di smalto (numerico con tre valori: \code{1}, \code{2} e \code{3})
#'  \item \code{Time} tempo necessario per sciogliere la macchia (minuti) (numerico)
#' }
#' 
#' 
NULL
##################################################################################################################################

##################################################################################################################################
#' Longitudine e Latitudine di Città Italiane
#' 
#' 
#' @name italy
#' 
#' 
#' @description Il dataset \code{italy} contiene informazioni su latitudine, longitudine, popolazione e regione delle città italiane più importanti. 
#'  
#' @usage data(italy)
#' 
#' 
#' @format \code{italy} è un data frame tbl con 56 osservazioni su 5 variabili.
#' 
#' 
#' @details 
#' Le 5 variabili del data frame tbl \code{italy} sono:
#' \itemize{
#'  \item \code{city} nome città (character)
#'  \item \code{lat} latitudine (numerico)
#'  \item \code{lon} longitudine (numerico)
#'  \item \code{pop} popolazione (numerico)
#'  \item \code{region} regione (character)
#' }
#' 
#' 
#' @source \url{http://simplemaps.com/resources/world-cities-data}
NULL
##################################################################################################################################

##################################################################################################################################
#' Dati su Cancro al Polmone dal NCCTG 
#' 
#' 
#' @name lung
#' 
#' 
#' @description Il dataset \code{lung} contiene informazioni sulla sopravvivenza di pazienti con cancro al polmone in uno stadio avanzato dal North Central Cancer Treatment Group. 
#' Alcuni punteggi di performance valutano quanto il paziente può svolgere attività quotidiane ordinarie
#' 
#' @usage data(lung)
#' 
#' 
#' @format \code{lung} è un data frame tbl con 228 osservazioni su 10 variabili.
#' 
#' 
#' @details 
#' Le 10 variabili del data frame tbl \code{lung} sono:
#' \itemize{
#'  \item \code{inst} Codice istituto (numerico)
#'  \item \code{time} Tempo di sopravvivenza in giorni (numerico)
#'  \item \code{status} Stato della censura 1=censurato, 2=morto (numerico)
#'  \item \code{age} Età in anni (numerico)
#'  \item \code{sex} Maschio=1 Femmina=2 (numerico)
#'  \item \code{ph.ecog} Punteggio di performance ECOG 0=buono 5=morto) (numeric)
#'  \item \code{ph.karno} Punteggio di performance Karnofsky (cattivo=0; buono=100) valutato del medico (numerico)
#'  \item \code{pat.karno} Punteggio di performance Karnofsky (cattivo=0; buono=100) valutato dal paziente (numerico)
#'  \item \code{meal.cal} Calorie consumate nei pasti (numerico)
#'  \item \code{wt.loss} Peso perso negli ultimi sei mesi (numerico)
#' }
#' 
#' 
#' @source La pagine di help completa di \code{lung} si trova nel package \code{Survival}: \code{\link[Survival]{lung}}
NULL
##################################################################################################################################

##################################################################################################################################
#' Crescita degli Alberi d'Arancia
#' 
#' 
#' @name orange
#' 
#' 
#' @description Il dataset \code{orange} contiene informazioni sulla crescita di 5 alber d'arancia, 
#' secondo la circonferenza dei loro tronchi.
#' 
#' @usage data(orange)
#' 
#' 
#' @format \code{orange} è un data frame tbl con 35 osservazioni su 3 variabili.
#' 
#' 
#' @details 
#' Le 3 variabili del data frame tbl \code{orange} sono:
#' \itemize{
#'  \item \code{Tree} id dell'albero (character)
#'  \item \code{age} età dell'albero (numerico)
#'  \item \code{circumference} circonferenza dell'albero (mm) (numerico)
#' }
#' 
#' 
#' @source Il dataset originario \code{Orange} è incluso nel package \code{Datasets}.
NULL
##################################################################################################################################


##################################################################################################################################
#' Caratteristiche degli Stati U.S.A.
#' 
#' 
#' @name states
#' 
#' 
#' @description Il dataset \code{states} contiene informazioni demografiche, economiche, geographiche e sociali sugli stati degli U.S.A.
#' 
#' @usage data(states)
#' 
#' 
#' @format \code{states} è un data frame tbl con 50 osservazioni su 11 variabili.
#' 
#' 
#' @details 
#' Le 11 variabili del data frame tbl \code{states} sono:
#' \itemize{
#'  \item \code{Population} popolazione (numerico)
#'  \item \code{Income} reddito (numerico)
#'  \item \code{Illiteracy} tasso di analfabetismo (numerico)
#'  \item \code{Life.Exp} vita attesa (character)
#'  \item \code{Murder} tasso di omicidi (numerico)
#'  \item \code{HS.Grad} punteggio di diploma in scuola superiore (numerico)
#'  \item \code{Frost} gelo (numerico)
#'  \item \code{Area} area (km^2) (numerico)
#'  \item \code{state.name} nome dello stato (fattore con 50 livelli)
#'  \item \code{state.region} regione dello stato (fattore con 4 livelli: \code{South}, \code{West}, \code{Northeast} e \code{North Central})
#'  \item \code{states.region.abb} abbreviazione della regione dello stato (fattore con 4 livelli: \code{S}, \code{W}, \code{N} e \code{C})
#' }
#' 
#' 
NULL
##################################################################################################################################
